import * as i0 from '@angular/core';
import { Injectable, Input, Component, NgModule, inject, booleanAttribute, ChangeDetectionStrategy, ChangeDetectorRef, NgZone, TemplateRef, HostBinding, ViewChild, ViewEncapsulation } from '@angular/core';
import * as i1 from '@angular/platform-browser';
import createDOMPurify from 'dompurify';
import * as i1$3 from '@skyux/forms';
import { SkyInputBoxModule, SkyCheckboxModule, SkyInputBoxHostService, SkyRequiredStateDirective, SkyFormErrorsModule, SKY_FORM_ERRORS_ENABLED, SkyFormErrorModule } from '@skyux/forms';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i1$2 from '@angular/forms';
import { FormsModule, NgControl } from '@angular/forms';
import * as i3 from '@skyux/core';
import { SkyIdModule, SkyCoreAdapterService, SkyIdService } from '@skyux/core';
import * as i3$2 from '@skyux/help-inline';
import { SkyHelpInlineModule } from '@skyux/help-inline';
import * as i6 from '@skyux/layout';
import { SkyToolbarModule } from '@skyux/layout';
import * as i4 from '@skyux/theme';
import { SkyThemeModule } from '@skyux/theme';
import { take, Subject } from 'rxjs';
import { takeUntil, take as take$1 } from 'rxjs/operators';
import * as i3$1 from '@skyux/i18n';
import { SkyLibResourcesService, SkyI18nModule } from '@skyux/i18n';
import * as i2 from '@skyux/popovers';
import { SkyDropdownMessageType, SkyDropdownModule } from '@skyux/popovers';
import he from 'he';
import * as i4$1 from '@skyux/colorpicker';
import { SkyColorpickerMessageType, SkyColorpickerModule } from '@skyux/colorpicker';
import * as i6$1 from '@skyux/icon';
import { SkyIconModule } from '@skyux/icon';
import * as i2$1 from '@skyux/modals';
import { SkyModalInstance, SkyModalModule, SkyModalService } from '@skyux/modals';
import * as i5 from '@skyux/tabs';
import { SkyTabsModule } from '@skyux/tabs';
import { SkyValidation } from '@skyux/validation';

const domPurify = createDOMPurify(window);
domPurify.addHook('afterSanitizeAttributes', (node) => {
    // Set all elements owning target to target=_blank
    // so we only allow the target attribute with that value.
    if (node.getAttribute('target')) {
        node.setAttribute('target', '_blank');
        node.setAttribute('rel', 'noopener noreferrer');
    }
});
/**
 * The `SkyTextSanitizationService` user the `DOMPurify` library to sanitize strings for use
 * in the DOM. `DOMPurify` allows more customization than Angular's internal `DomSanitizer` so we
 * can preserve `<style>` tags and allow `target` attributes for new tab links.
 * @internal
 */
class SkyTextSanitizationService {
    #allowedAttributes = ['target'];
    /**
     * Returns a sanitized string, allowing target attribute for new tab links.
     */
    sanitize(htmlString) {
        return domPurify.sanitize(htmlString, {
            ADD_ATTR: this.#allowedAttributes,
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextSanitizationService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextSanitizationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextSanitizationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class SkyRichTextDisplayComponent {
    /**
     * The rich text to display.
     */
    set richText(value) {
        if (value) {
            const cleaned = this.#sanitizationService.sanitize(value);
            /* istanbul ignore else */
            if (cleaned !== this.#_richText) {
                this.#_richText = cleaned;
                // Text has already been sanitized with DOMPurifier.
                // Tell Angular to bypass its own internal sanitization.
                this.sanitizedText = this.#sanitizer.bypassSecurityTrustHtml(cleaned);
            }
        }
        else {
            this.#_richText = '';
            this.sanitizedText = '';
        }
    }
    #_richText;
    #sanitizer;
    #sanitizationService;
    constructor(sanitizer, sanitizationService) {
        this.sanitizedText = '';
        this.#_richText = '';
        this.#sanitizer = sanitizer;
        this.#sanitizationService = sanitizationService;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayComponent, deps: [{ token: i1.DomSanitizer }, { token: SkyTextSanitizationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: SkyRichTextDisplayComponent, isStandalone: false, selector: "sky-rich-text-display", inputs: { richText: "richText" }, ngImport: i0, template: "<span class=\"sky-rich-text-display-text\" [innerHTML]=\"sanitizedText\"></span>\n" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sky-rich-text-display', standalone: false, template: "<span class=\"sky-rich-text-display-text\" [innerHTML]=\"sanitizedText\"></span>\n" }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }, { type: SkyTextSanitizationService }], propDecorators: { richText: [{
                type: Input
            }] } });

class SkyRichTextDisplayModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayModule, declarations: [SkyRichTextDisplayComponent], exports: [SkyRichTextDisplayComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyRichTextDisplayModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [SkyRichTextDisplayComponent],
                    declarations: [SkyRichTextDisplayComponent],
                }]
        }] });

/* istanbul ignore file */
/**
 * NOTICE: DO NOT MODIFY THIS FILE!
 * The contents of this file were automatically generated by
 * the 'ng generate @skyux/i18n:lib-resources-module lib/modules/shared/sky-text-editor' schematic.
 * To update this file, simply rerun the command.
 */
const RESOURCES = {
    'EN-US': {
        skyux_text_editor_format_menu_action_bold_label: { message: 'Bold' },
        skyux_text_editor_format_menu_action_bold_key_shortcut: {
            message: 'Ctrl+B',
        },
        skyux_text_editor_format_menu_action_italic_label: { message: 'Italic' },
        skyux_text_editor_format_menu_action_italic_key_shortcut: {
            message: 'Ctrl+I',
        },
        skyux_text_editor_format_menu_action_underline_label: {
            message: 'Underline',
        },
        skyux_text_editor_format_menu_action_underline_key_shortcut: {
            message: 'Ctrl+U',
        },
        skyux_text_editor_format_menu_action_strikethrough_label: {
            message: 'Strikethrough',
        },
        skyux_text_editor_format_menu_action_clear_formatting_label: {
            message: 'Clear formatting',
        },
        skyux_text_editor_edit_menu_action_undo_label: { message: 'Undo' },
        skyux_text_editor_edit_menu_action_undo_key_shortcut: { message: 'Ctrl+Z' },
        skyux_text_editor_edit_menu_action_redo_label: { message: 'Redo' },
        skyux_text_editor_edit_menu_action_redo_key_shortcut: { message: 'Ctrl+Y' },
        skyux_text_editor_edit_menu_action_cut_label: { message: 'Cut' },
        skyux_text_editor_edit_menu_action_cut_key_shortcut: { message: 'Ctrl+X' },
        skyux_text_editor_edit_menu_action_copy_label: { message: 'Copy' },
        skyux_text_editor_edit_menu_action_copy_key_shortcut: { message: 'Ctrl+C' },
        skyux_text_editor_edit_menu_action_paste_label: { message: 'Paste' },
        skyux_text_editor_edit_menu_action_paste_key_shortcut: {
            message: 'Ctrl+V',
        },
        skyux_text_editor_edit_menu_action_select_all_label: {
            message: 'Select all',
        },
        skyux_text_editor_edit_menu_action_select_all_key_shortcut: {
            message: 'Ctrl+A',
        },
        skyux_text_editor_iframe_title_default: { message: 'Text editor' },
        skyux_text_editor_menubar_dropdown_button_edit_label: { message: 'Edit' },
        skyux_text_editor_menubar_dropdown_button_format_label: {
            message: 'Format',
        },
        skyux_text_editor_menubar_dropdown_button_insert_label: {
            message: 'Insert merge field',
        },
        skyux_text_editor_paste_incompatibility_error: {
            message: 'Direct clipboard access is not supported by this browser. Use the Ctrl+X/C/V keyboard shortcuts instead.',
        },
        skyux_text_editor_url_modal_header_label: { message: 'Create link' },
        skyux_text_editor_url_modal_url_label: {
            message: 'Enter a URL to link to:',
        },
        skyux_text_editor_url_modal_open_label: {
            message: 'Where should it open?',
        },
        skyux_text_editor_url_modal_current_option_label: {
            message: 'Current window',
        },
        skyux_text_editor_url_modal_open_in_new_window_label: {
            message: 'This link will open in a new window.',
        },
        skyux_text_editor_url_modal_new_option_label: { message: 'New window' },
        skyux_text_editor_url_modal_email_label: { message: 'Email address' },
        skyux_text_editor_url_modal_subject_label: { message: 'Subject line' },
        skyux_text_editor_url_modal_save_button_label: { message: 'Save' },
        skyux_text_editor_url_modal_cancel_button_label: { message: 'Cancel' },
    },
    'FR-CA': {
        skyux_text_editor_format_menu_action_bold_label: { message: 'Gras' },
        skyux_text_editor_format_menu_action_bold_key_shortcut: {
            message: 'Ctrl+B',
        },
        skyux_text_editor_format_menu_action_italic_label: { message: 'Italique' },
        skyux_text_editor_format_menu_action_italic_key_shortcut: {
            message: 'Ctrl+I',
        },
        skyux_text_editor_format_menu_action_underline_label: {
            message: 'Souligner',
        },
        skyux_text_editor_format_menu_action_underline_key_shortcut: {
            message: 'Ctrl+U',
        },
        skyux_text_editor_format_menu_action_strikethrough_label: {
            message: 'Barrer',
        },
        skyux_text_editor_format_menu_action_clear_formatting_label: {
            message: 'Supprimer la mise en forme',
        },
        skyux_text_editor_edit_menu_action_undo_label: { message: 'Annuler' },
        skyux_text_editor_edit_menu_action_undo_key_shortcut: { message: 'Ctrl+Z' },
        skyux_text_editor_edit_menu_action_redo_label: { message: 'Rétablir' },
        skyux_text_editor_edit_menu_action_redo_key_shortcut: { message: 'Ctrl+Y' },
        skyux_text_editor_edit_menu_action_cut_label: { message: 'Couper' },
        skyux_text_editor_edit_menu_action_cut_key_shortcut: { message: 'Ctrl+X' },
        skyux_text_editor_edit_menu_action_copy_label: { message: 'Copier' },
        skyux_text_editor_edit_menu_action_copy_key_shortcut: { message: 'Ctrl+C' },
        skyux_text_editor_edit_menu_action_paste_label: { message: 'Coller' },
        skyux_text_editor_edit_menu_action_paste_key_shortcut: {
            message: 'Ctrl+V',
        },
        skyux_text_editor_edit_menu_action_select_all_label: {
            message: 'Sélectionner tout',
        },
        skyux_text_editor_edit_menu_action_select_all_key_shortcut: {
            message: 'Ctrl+A',
        },
        skyux_text_editor_iframe_title_default: { message: 'Éditeur de texte' },
        skyux_text_editor_menubar_dropdown_button_edit_label: {
            message: 'Modifier',
        },
        skyux_text_editor_menubar_dropdown_button_format_label: {
            message: 'Format',
        },
        skyux_text_editor_menubar_dropdown_button_insert_label: {
            message: 'Insérer un champ de fusion',
        },
        skyux_text_editor_paste_incompatibility_error: {
            message: 'L’accès direct au presse-papiers n’est pas pris en charge par ce navigateur. Utilisez plutôt les raccourcis-clavier Ctrl+X/C/V.',
        },
        skyux_text_editor_url_modal_header_label: { message: 'Créer le lien' },
        skyux_text_editor_url_modal_url_label: {
            message: 'Saisir une URL à lier à :',
        },
        skyux_text_editor_url_modal_open_label: {
            message: 'Où devrait-elle s’ouvrir?',
        },
        skyux_text_editor_url_modal_current_option_label: {
            message: 'Fenêtre actuelle',
        },
        skyux_text_editor_url_modal_open_in_new_window_label: {
            message: 'Ce lien s’ouvrira dans une nouvelle fenêtre',
        },
        skyux_text_editor_url_modal_new_option_label: {
            message: 'Nouvelle fenêtre',
        },
        skyux_text_editor_url_modal_email_label: { message: 'Adresse de courriel' },
        skyux_text_editor_url_modal_subject_label: {
            message: 'Ligne de mention objet',
        },
        skyux_text_editor_url_modal_save_button_label: { message: 'Sauvegarder' },
        skyux_text_editor_url_modal_cancel_button_label: { message: 'Annuler' },
    },
};
SkyLibResourcesService.addResources(RESOURCES);
/**
 * Import into any component library module that needs to use resource strings.
 */
class SkyTextEditorResourcesModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorResourcesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorResourcesModule, exports: [SkyI18nModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorResourcesModule, imports: [SkyI18nModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorResourcesModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [SkyI18nModule],
                }]
        }] });

/**
 * @internal
 */
const FONT_LIST_DEFAULTS = [
    {
        name: 'Blackbaud Sans',
        value: '"Blackbaud Sans", Arial, sans-serif',
    },
    {
        name: 'Arial',
        value: 'Arial',
    },
    {
        name: 'Arial Black',
        value: '"Arial Black"',
    },
    {
        name: 'Courier New',
        value: '"Courier New"',
    },
    {
        name: 'Georgia',
        value: 'Georgia, serif',
    },
    {
        name: 'Tahoma',
        value: 'Tahoma, Geneva, sans-serif',
    },
    {
        name: 'Times New Roman',
        value: '"Times New Roman"',
    },
    {
        name: 'Trebuchet MS',
        value: '"Trebuchet MS", sans-serif',
    },
    {
        name: 'Verdana',
        value: 'Verdana, Geneva, sans-serif',
    },
];

/**
 * @internal
 */
const FONT_SIZE_LIST_DEFAULTS = [
    6, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 20, 22, 24, 26, 28, 36, 48,
];

const LINK_WINDOW_OPTIONS_DEFAULTS = ['new', 'existing'];

/**
 * @internal
 */
const MENU_DEFAULTS = ['edit', 'format'];

/**
 * @internal
 */
const STYLE_STATE_DEFAULTS = {
    backColor: 'rgba(0, 0, 0, 0)',
    fontColor: '#000',
    fontSize: 14,
    font: FONT_LIST_DEFAULTS[0].value,
    boldState: false,
    italicState: false,
    underlineState: false,
    linkState: false,
};

/**
 * @internal
 */
const TOOLBAR_ACTION_DEFAULTS = [
    'font-family',
    'font-size',
    'font-style',
    'color',
    'list',
    'link',
];

/**
 * @internal
 */
var UrlTarget;
(function (UrlTarget) {
    UrlTarget[UrlTarget["None"] = 0] = "None";
    UrlTarget[UrlTarget["NewWindow"] = 1] = "NewWindow";
})(UrlTarget || (UrlTarget = {}));

/**
 * @internal
 */
class SkyTextEditorSelectionService {
    isElementSelected(documentEl, element) {
        const selectedNode = this.getCurrentSelection(documentEl)?.anchorNode;
        /* istanbul ignore next */
        return !!(selectedNode &&
            (element.contains(selectedNode) ||
                (selectedNode.parentNode && element.contains(selectedNode.parentNode))));
    }
    getCurrentSelection(documentEl) {
        return documentEl.getSelection();
    }
    getCurrentSelectionParentElement(documentEl) {
        const selection = this.getCurrentSelection(documentEl);
        let selectedEl;
        /* istanbul ignore else */
        if (selection &&
            selection.getRangeAt &&
            selection.getRangeAt(0).commonAncestorContainer) {
            selectedEl = selection.getRangeAt(0).commonAncestorContainer;
            selectedEl =
                selectedEl.nodeType !== 1 ? selectedEl.parentElement : selectedEl;
        }
        else {
            return undefined;
        }
        return selectedEl;
    }
    getCurrentSelectionRange(documentEl, windowEl) {
        /* istanbul ignore else */
        if (windowEl.getSelection) {
            const sel = windowEl.getSelection();
            /* istanbul ignore else */
            if (sel && sel.getRangeAt && sel.rangeCount) {
                return sel.getRangeAt(0);
            }
        }
        else if (documentEl.getSelection()?.getRangeAt) {
            return documentEl.getSelection()?.getRangeAt(0);
        }
        /* istanbul ignore next */
        return undefined;
    }
    selectElement(documentEl, windowEl, element) {
        /* istanbul ignore else */
        if (element) {
            /* istanbul ignore else */
            if (windowEl.getSelection) {
                const sel = windowEl.getSelection();
                sel?.removeAllRanges();
                const range = documentEl.createRange();
                range.selectNodeContents(element);
                sel?.addRange(range);
            }
            else if (documentEl.getSelection) {
                const sel = documentEl.getSelection();
                sel?.removeAllRanges();
                const range = documentEl.createRange();
                range.selectNodeContents(element);
                sel?.addRange(range);
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorSelectionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorSelectionService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorSelectionService, decorators: [{
            type: Injectable
        }] });

/**
 * @internal
 */
class SkyTextEditorService {
    /**
     * A dictionary representing all active text editors and their settings.
     */
    set editor(value) {
        this.#editor = value;
    }
    get editor() {
        if (!this.#editor) {
            throw new Error('Editor has not been initialized.');
        }
        return this.#editor;
    }
    get isInitialized() {
        return this.#editor !== undefined;
    }
    #editor;
    /**
     * Returns the blur observable from the editor with the corresponding id.
     */
    blurListener() {
        return this.editor.blurObservable;
    }
    /**
     * Returns the click observable from the editor with the corresponding id.
     */
    clickListener() {
        return this.editor.clickObservable;
    }
    /**
     * Returns the command change observable from the editor with the corresponding id.
     */
    commandChangeListener() {
        return this.editor.commandChangeObservable;
    }
    /**
     * Returns the focus observable from the editor with the corresponding id.
     */
    focusListener() {
        return this.editor.focusObservable;
    }
    /**
     * Returns the input change observable from the editor with the corresponding id.
     */
    inputListener() {
        return this.editor.inputObservable;
    }
    /**
     * Returns the selection change observable from the editor with the corresponding id.
     */
    selectionChangeListener() {
        return this.editor.selectionChangeObservable;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorService, decorators: [{
            type: Injectable
        }] });

/**
 * @internal
 */
class SkyTextEditorAdapterService {
    #resourceSvc = inject(SkyLibResourcesService);
    #selectionService;
    #textEditorService;
    #windowRef;
    constructor(selectionService, textEditorService, windowService) {
        this.#selectionService = selectionService;
        this.#textEditorService = textEditorService;
        this.#windowRef = windowService;
    }
    /**
     * Creates a text editor inside the supplied iframe element.
     */
    initEditor(id, iframeElement, styleState, placeholder) {
        this.#textEditorService.editor = this.#createObservers(iframeElement);
        const documentEl = this.#getIframeDocumentEl();
        if (!documentEl) {
            return;
        }
        const styleEl = documentEl.createElement('style');
        styleEl.innerHTML = `.editor:empty:before {
      content: attr(data-placeholder);
      font-family: "Blackbaud Sans", Arial, sans-serif;
      color: #686c73;
      font-weight: 400;
      font-size: 15px;
      font-style: italic;
    }`;
        documentEl.head.appendChild(styleEl);
        const style = {
            ...STYLE_STATE_DEFAULTS,
            ...styleState,
        };
        const bodyStyle = `background-color: ${style.backColor};
      color: ${style.fontColor};
      font-family: ${style.font};
      font-size: ${style.fontSize}px`;
        documentEl.querySelector('html')?.setAttribute('lang', 'en');
        documentEl.body.setAttribute('contenteditable', 'true');
        documentEl.body.setAttribute('id', id);
        documentEl.body.setAttribute('role', 'main');
        documentEl.body.setAttribute('class', 'editor');
        documentEl.body.setAttribute('style', bodyStyle);
        documentEl.body.setAttribute('data-placeholder', placeholder || '');
    }
    disableEditor(focusableChildren, textEditorNativeElement) {
        this.#setEditorDisabled(focusableChildren, textEditorNativeElement, true);
    }
    enableEditor(focusableChildren, textEditorNativeElement) {
        this.#setEditorDisabled(focusableChildren, textEditorNativeElement, false);
    }
    /**
     * Executes a command on the text editor with the corresponding id.
     */
    async execCommand(editorCommand) {
        /* istanbul ignore else */
        if (this.#textEditorService.editor) {
            const documentEl = this.#getIframeDocumentEl();
            if (editorCommand.command === 'paste') {
                // Firefox does not support the clipboard API's `readText` as of 3/24. We are ok with just firing an alert when the paste button is used in Firefox.
                if (!navigator.clipboard.readText) {
                    this.#resourceSvc
                        .getString('skyux_text_editor_paste_incompatibility_error')
                        .pipe(take(1))
                        .subscribe((errorString) => alert(errorString));
                }
                else {
                    await navigator.clipboard.readText().then((clipText) => {
                        /* istanbul ignore else */
                        if (this.editorSelected()) {
                            documentEl?.execCommand('insertHTML', false, clipText);
                            this.focusEditor();
                            this.#textEditorService.editor.commandChangeObservable.next();
                        }
                    });
                }
            }
            else {
                /* istanbul ignore else */
                if (this.editorSelected()) {
                    documentEl?.execCommand(editorCommand.command, false, editorCommand.value);
                    this.focusEditor();
                    this.#textEditorService.editor.commandChangeObservable.next();
                }
            }
        }
    }
    getCurrentSelection() {
        const documentEl = this.#getIframeDocumentEl();
        if (documentEl) {
            return this.#selectionService.getCurrentSelection(documentEl);
        }
        return null;
    }
    /**
     * Returns a data URI using the provided text string.
     * Used to display a merge field inside a string of text.
     */
    getMergeFieldDataURI(text) {
        const documentEl = this.#windowRef.nativeWindow.document;
        let textToUse = text;
        if (text.length > 18) {
            textToUse = text.substr(0, 15) + '...';
        }
        const canvasElement = documentEl.createElement('canvas');
        canvasElement.setAttribute('height', '20');
        canvasElement.setAttribute('width', '100');
        canvasElement.style.backgroundColor = 'tan';
        canvasElement.style.border = '1px solid #000000';
        canvasElement.style.borderRadius = '5px';
        const context = canvasElement.getContext('2d');
        context.font = '12px Arial';
        context.textAlign = 'center';
        context.fillText(textToUse, 50, 15);
        context.globalCompositeOperation = 'destination-over';
        context.fillStyle = '#00FFFF';
        context.fillRect(0, 0, 100, 20);
        context.globalCompositeOperation = 'source-over';
        context.lineWidth = 2;
        context.strokeStyle = '#FF0000';
        context.strokeRect(0, 0, 100, 20);
        const result = canvasElement.toDataURL('image/png', 1.0);
        return result;
    }
    getStyleState() {
        const documentEl = this.#getIframeDocumentEl();
        /* istanbul ignore else */
        if (documentEl && this.editorSelected()) {
            return {
                backColor: this.#getColor(documentEl, 'BackColor'),
                fontColor: this.#getColor(documentEl, 'ForeColor'),
                fontSize: parseInt(this.#getFontSize(), undefined),
                font: documentEl.queryCommandValue('fontname'),
                boldState: documentEl.queryCommandState('Bold'),
                italicState: documentEl.queryCommandState('Italic'),
                underlineState: documentEl.queryCommandState('Underline'),
                linkState: this.#hasLink(),
            };
        }
        /* istanbul ignore next */
        return {};
    }
    getEditorInnerHtml() {
        const documentEl = this.#getIframeDocumentEl();
        if (documentEl) {
            return this.#replaceHtmlCodes(documentEl.body.innerHTML);
        }
        return '';
    }
    setEditorInnerHtml(value) {
        const documentEl = this.#getIframeDocumentEl();
        const editorContent = documentEl?.body;
        /* istanbul ignore else */
        if (editorContent && editorContent.innerHTML !== value) {
            editorContent.innerHTML = value;
        }
    }
    focusEditor() {
        /* istanbul ignore else */
        if (this.#textEditorService.editor) {
            const windowEl = this.#getContentWindowEl();
            const iframeDocumentEl = this.#getIframeDocumentEl();
            if (windowEl && iframeDocumentEl) {
                const currentSelection = this.#selectionService.getCurrentSelectionRange(iframeDocumentEl, windowEl);
                const cursorIsNotActiveAndHasReset = currentSelection &&
                    currentSelection.startOffset === 0 &&
                    currentSelection.endOffset === 0;
                if (!this.editorSelected() || cursorIsNotActiveAndHasReset) {
                    // focus the end of the editor
                    const documentEl = this.#windowRef.nativeWindow.document;
                    const editor = iframeDocumentEl.body;
                    const range = documentEl.createRange();
                    this.#textEditorService.editor.iframeElementRef.focus();
                    editor.focus();
                    if (windowEl.getSelection && documentEl.createRange) {
                        range.selectNodeContents(editor);
                        range.collapse(false);
                        const sel = windowEl.getSelection();
                        sel?.removeAllRanges();
                        sel?.addRange(range);
                    }
                }
                else {
                    // Cursor may not be active, restore it
                    this.#textEditorService.editor.iframeElementRef.focus();
                    iframeDocumentEl.body.focus();
                }
            }
        }
    }
    getLink() {
        let link;
        const anchorEl = this.getSelectedAnchorTag();
        if (anchorEl && anchorEl.href) {
            link = {
                target: anchorEl.getAttribute('target') === '_blank'
                    ? UrlTarget.NewWindow
                    : UrlTarget.None,
                url: anchorEl.href,
            };
        }
        return link;
    }
    getSelectedAnchorTag() {
        const selectedEl = this.#getCurrentSelectionParentElement();
        if (selectedEl) {
            return this.#getParent(selectedEl, 'a');
        }
        return undefined;
    }
    saveSelection() {
        const documentEl = this.#getIframeDocumentEl();
        const windowEl = this.#getContentWindowEl();
        if (documentEl && windowEl) {
            return this.#selectionService.getCurrentSelectionRange(documentEl, windowEl);
        }
        return undefined;
    }
    selectElement(element) {
        const documentEl = this.#getIframeDocumentEl();
        const windowEl = this.#getContentWindowEl();
        if (documentEl && windowEl) {
            this.#selectionService.selectElement(documentEl, windowEl, element);
        }
    }
    setErrorAttributes(errorId, errors) {
        const documentEl = this.#getIframeDocumentEl();
        documentEl?.body.setAttribute('aria-invalid', (!!errors).toString());
        if (errors && errorId) {
            documentEl?.body.setAttribute('aria-errormessage', errorId);
        }
        else {
            documentEl?.body.removeAttribute('aria-errormessage');
        }
    }
    setLabelAttribute(label) {
        if (label) {
            const documentEl = this.#getIframeDocumentEl();
            documentEl?.body.setAttribute('aria-label', label);
        }
    }
    setPlaceholder(placeholder) {
        const documentEl = this.#getIframeDocumentEl();
        documentEl?.body.setAttribute('data-placeholder', placeholder || '');
    }
    setRequiredAttribute(required) {
        const documentEl = this.#getIframeDocumentEl();
        documentEl?.body.setAttribute('aria-required', required.toString());
    }
    async setFontSize(fontSize) {
        const doc = this.#getIframeDocumentEl();
        await this.execCommand({ command: 'fontSize', value: '1' });
        if (doc) {
            const fontElements = Array.from(doc.querySelectorAll('font[size="1"]'));
            for (const element of fontElements) {
                element.removeAttribute('size');
                element.style.fontSize = fontSize + 'px';
            }
            this.#cleanUpBlankStyleTags(doc);
        }
        this.focusEditor();
        this.#textEditorService.editor.commandChangeObservable.next();
    }
    removeObservers(setting) {
        /* istanbul ignore next */
        const documentEl = setting.iframeElementRef.contentWindow
            ? setting.iframeElementRef.contentWindow.document
            : setting.iframeElementRef.contentDocument;
        setting.selectionChangeObservable.complete();
        setting.clickObservable.complete();
        setting.commandChangeObservable.complete();
        if (documentEl) {
            documentEl.removeEventListener('selectionchange', setting.selectionListener);
            documentEl.removeEventListener('input', setting.selectionListener);
            documentEl.removeEventListener('mousedown', setting.clickListener);
            documentEl.body.removeEventListener('paste', setting.pasteListener);
        }
    }
    #getContentWindowEl() {
        return this.#textEditorService.editor.iframeElementRef
            .contentWindow;
    }
    #getChildSelectedAnchorTags() {
        const selectedRange = this.getCurrentSelection()?.getRangeAt(0);
        if (selectedRange && selectedRange.toString().length <= 0) {
            return [];
        }
        const parentElement = this.#getCurrentSelectionParentElement();
        let childElements = [];
        /* istanbul ignore else */
        if (parentElement) {
            childElements = Array.from(parentElement.querySelectorAll('a'));
        }
        /* istanbul ignore next */
        return childElements.filter((element) => {
            // IE specific
            if (selectedRange) {
                if (!selectedRange.intersectsNode) {
                    if (!element || !element.href) {
                        return false;
                    }
                    const tempRange = document.createRange();
                    tempRange.selectNodeContents(element);
                    return ((selectedRange.compareBoundaryPoints(Range.START_TO_START, tempRange) !== -1 &&
                        selectedRange.compareBoundaryPoints(Range.START_TO_END, tempRange) !== 1) ||
                        (selectedRange.compareBoundaryPoints(Range.END_TO_START, tempRange) !== -1 &&
                            selectedRange.compareBoundaryPoints(Range.END_TO_END, tempRange) !== 1));
                }
            }
            // Normal non-IE
            return (!!element && !!element.href && selectedRange?.intersectsNode(element));
        });
    }
    #getIframeDocumentEl() {
        const contentWindowEl = this.#getContentWindowEl();
        /* istanbul ignore else */
        if (contentWindowEl) {
            return contentWindowEl.document;
        }
        /* istanbul ignore next */
        return this.#textEditorService.editor.iframeElementRef
            .contentDocument;
    }
    #getFontSize() {
        let fontSize = STYLE_STATE_DEFAULTS.fontSize.toString();
        const selection = this.getCurrentSelection();
        /* istanbul ignore else */
        if (selection &&
            selection.anchorNode &&
            selection.anchorNode.parentElement) {
            let element = selection.anchorNode;
            if (element?.nodeType !== 1) {
                element = element?.parentElement;
            }
            const computedStyle = window.getComputedStyle(element);
            /* istanbul ignore else */
            if (computedStyle) {
                fontSize = computedStyle.getPropertyValue('font-size');
            }
        }
        return fontSize;
    }
    #createObservers(element) {
        /* istanbul ignore next */
        const documentEl = element.contentWindow
            ? element.contentWindow.document
            : element.contentDocument;
        // Firefox bug where we need to open/close to cancel load so it doesn't overwrite attrs
        documentEl?.open();
        documentEl?.close();
        const selectionObservable = new Subject();
        const selectionListener = () => selectionObservable.next();
        const clickObservable = new Subject();
        const clickListener = () => clickObservable.next();
        const pasteListener = this.#getPasteOverride();
        const blurObservable = new Subject();
        const blurListener = () => blurObservable.next();
        const focusObservable = new Subject();
        const focusListener = () => focusObservable.next();
        const inputObservable = new Subject();
        const inputListener = () => inputObservable.next();
        documentEl?.addEventListener('selectionchange', selectionListener);
        documentEl?.addEventListener('input', inputListener);
        documentEl?.addEventListener('mousedown', clickListener);
        documentEl?.body.addEventListener('paste', pasteListener);
        documentEl?.body.addEventListener('blur', blurListener);
        documentEl?.body.addEventListener('focusin', focusListener);
        return {
            blurObservable,
            clickObservable,
            focusObservable,
            commandChangeObservable: new Subject(),
            iframeElementRef: element,
            inputObservable,
            selectionChangeObservable: selectionObservable,
            blurListener,
            focusListener,
            clickListener,
            inputListener,
            pasteListener,
            selectionListener,
        };
    }
    #getPasteOverride() {
        /* istanbul ignore next */
        return (e) => {
            e.preventDefault();
            const text = e.clipboardData?.getData('text/plain');
            if (text !== undefined) {
                void this.execCommand({
                    command: 'insertHTML',
                    value: text.toString(),
                });
            }
        };
    }
    #getCurrentSelectionParentElement() {
        const documentEl = this.#getIframeDocumentEl();
        if (documentEl) {
            return this.#selectionService.getCurrentSelectionParentElement(documentEl);
        }
        return undefined;
    }
    #getColor(documentEl, selector) {
        const commandValue = documentEl.queryCommandValue(selector);
        // Edge is weird and returns numbers
        /* istanbul ignore if */
        if (typeof commandValue === 'number') {
            /* istanbul ignore next */
            return ('rgb(' +
                (commandValue & 0xff) +
                ', ' +
                ((commandValue & 0xff00) >> 8) +
                ', ' +
                ((commandValue & 0xff0000) >> 16) +
                ')');
        }
        // Firefox uses 'Transparent' instead of a color value
        /* istanbul ignore next */
        if (commandValue.toString().toLowerCase() === 'transparent') {
            return STYLE_STATE_DEFAULTS.backColor;
        }
        return commandValue;
    }
    #hasLink() {
        const anchorEl = this.getSelectedAnchorTag();
        const childAnchorEls = this.#getChildSelectedAnchorTags();
        /* istanbul ignore next */
        return childAnchorEls.length > 0 || (!!anchorEl && !!anchorEl.href);
    }
    #getParent(element, tag) {
        let currentNode = element;
        while (currentNode && currentNode.tagName.toUpperCase() !== 'BODY') {
            if (currentNode.tagName.toUpperCase() === tag.toUpperCase()) {
                return currentNode;
            }
            currentNode = currentNode.parentElement;
        }
        return undefined;
    }
    editorSelected() {
        const documentEl = this.#getIframeDocumentEl();
        if (documentEl) {
            return this.#selectionService.isElementSelected(documentEl, documentEl.body);
        }
        return false;
    }
    #cleanUpBlankStyleTags(doc) {
        const orphanElements = Array.from(doc.querySelectorAll('font,span,*[style=""]'));
        for (const element of orphanElements) {
            if (!element.getAttribute('style')) {
                element.removeAttribute('style');
            }
        }
        const removableElements = orphanElements.filter((element) => {
            const tagName = element.tagName.toUpperCase();
            return ((tagName === 'FONT' || tagName === 'SPAN') &&
                (element.attributes.length === 0 || !element.hasChildNodes));
        });
        for (const element of removableElements) {
            const parent = element.parentNode;
            /* istanbul ignore else */
            if (parent) {
                while (element.firstChild) {
                    parent.insertBefore(element.firstChild, element);
                }
                parent.removeChild(element);
            }
        }
    }
    // Certain values are encoded in html and need to be decoded
    #replaceHtmlCodes(str) {
        return str
            .replace(/&nbsp;/, String.fromCharCode(160))
            .replace(/&lt;/g, '<')
            .replace(/&gt;/g, '>')
            .replace(/&amp;/g, '&');
    }
    #setEditorDisabled(focusableChildren, textEditorNativeElement, disabled) {
        textEditorNativeElement.style.pointerEvents = disabled ? 'none' : 'auto';
        textEditorNativeElement.setAttribute('aria-disabled', disabled ? 'true' : 'false');
        /* istanbul ignore else */
        if (focusableChildren.length > 0) {
            focusableChildren.forEach((aFocusableChild) => {
                aFocusableChild.tabIndex = disabled ? -1 : 0;
            });
        }
        this.#getIframeDocumentEl()?.body.setAttribute('contenteditable', disabled ? 'false' : 'true');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorAdapterService, deps: [{ token: SkyTextEditorSelectionService }, { token: SkyTextEditorService }, { token: i3.SkyAppWindowRef }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorAdapterService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorAdapterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: SkyTextEditorSelectionService }, { type: SkyTextEditorService }, { type: i3.SkyAppWindowRef }] });

const FORMAT_MENU_ACTION = 'skyux_text_editor_format_menu_action_';
const EDIT_MENU_ACTION = 'skyux_text_editor_edit_menu_action_';
/**
 * @internal
 */
class SkyTextEditorMenubarComponent {
    constructor() {
        this.editorFocusStream = new Subject();
        this.menus = [];
        this.mergeFields = [];
        this.disabled = false;
        this.editDropdownStream = new Subject();
        this.formatDropdownStream = new Subject();
        this.mergeFieldDropdownStream = new Subject();
        this.#ngUnsubscribe = new Subject();
        this.#adapterService = inject(SkyTextEditorAdapterService);
        this.#resources = inject(SkyLibResourcesService);
    }
    #ngUnsubscribe;
    #adapterService;
    #resources;
    ngOnInit() {
        this.editorFocusStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.#closeDropdowns();
        });
        this.#resources
            .getStrings({
            bold: FORMAT_MENU_ACTION + 'bold_label',
            boldShort: FORMAT_MENU_ACTION + 'bold_key_shortcut',
            italic: FORMAT_MENU_ACTION + 'italic_label',
            italicShort: FORMAT_MENU_ACTION + 'italic_key_shortcut',
            underline: FORMAT_MENU_ACTION + 'underline_label',
            underlineShort: FORMAT_MENU_ACTION + 'underline_key_shortcut',
            strikethrough: FORMAT_MENU_ACTION + 'strikethrough_label',
            clearFormatting: FORMAT_MENU_ACTION + 'clear_formatting_label',
            undo: EDIT_MENU_ACTION + 'undo_label',
            undoShort: EDIT_MENU_ACTION + 'undo_key_shortcut',
            redo: EDIT_MENU_ACTION + 'redo_label',
            redoShort: EDIT_MENU_ACTION + 'redo_key_shortcut',
            cut: EDIT_MENU_ACTION + 'cut_label',
            cutShort: EDIT_MENU_ACTION + 'cut_key_shortcut',
            copy: EDIT_MENU_ACTION + 'copy_label',
            copyShort: EDIT_MENU_ACTION + 'copy_key_shortcut',
            paste: EDIT_MENU_ACTION + 'paste_label',
            pasteShort: EDIT_MENU_ACTION + 'paste_key_shortcut',
            selectAll: EDIT_MENU_ACTION + 'select_all_label',
            selectAllShort: EDIT_MENU_ACTION + 'select_all_key_shortcut',
        })
            .pipe(take$1(1), takeUntil(this.#ngUnsubscribe))
            .subscribe((resources) => {
            this.formatItems = [
                {
                    function: () => this.execCommand('bold'),
                    label: resources.bold,
                    keyShortcut: resources.boldShort,
                },
                {
                    function: () => this.execCommand('italic'),
                    label: resources.italic,
                    keyShortcut: resources.italicShort,
                },
                {
                    function: () => this.execCommand('underline'),
                    label: resources.underline,
                    keyShortcut: resources.underlineShort,
                },
                {
                    function: () => this.execCommand('strikethrough'),
                    label: resources.strikethrough,
                },
                {
                    isDivider: true,
                },
                {
                    function: () => this.#clearFormat(),
                    label: resources.clearFormatting,
                },
            ];
            this.editItems = [
                {
                    function: () => this.execCommand('undo'),
                    label: resources.undo,
                    keyShortcut: resources.undoShort,
                },
                {
                    function: () => this.execCommand('redo'),
                    label: resources.redo,
                    keyShortcut: resources.redoShort,
                },
                {
                    isDivider: true,
                },
                {
                    function: () => this.execCommand('cut'),
                    label: resources.cut,
                    keyShortcut: resources.cutShort,
                },
                {
                    function: () => this.execCommand('copy'),
                    label: resources.copy,
                    keyShortcut: resources.copyShort,
                },
                {
                    function: () => this.execCommand('paste'),
                    label: resources.paste,
                    keyShortcut: resources.pasteShort,
                },
                {
                    isDivider: true,
                },
                {
                    function: () => this.execCommand('selectAll'),
                    label: resources.selectAll,
                    keyShortcut: resources.selectAllShort,
                },
            ];
        });
    }
    ngOnDestroy() {
        this.#ngUnsubscribe.next();
        this.#ngUnsubscribe.complete();
    }
    execCommand(command, value = '') {
        void this.#adapterService.execCommand({
            command: command,
            value: value,
        });
    }
    insertMergeField(field) {
        this.execCommand('insertHTML', '<img style="display: inline; cursor: grab;" data-fieldid="' +
            he.escape(field.id) +
            '" data-fielddisplay="' +
            he.escape(field.name) +
            '" src="' +
            (field.previewImageUrl ||
                this.#adapterService.getMergeFieldDataURI(field.name)) +
            '">');
    }
    #closeDropdowns() {
        this.editDropdownStream.next({ type: SkyDropdownMessageType.Close });
        this.formatDropdownStream.next({ type: SkyDropdownMessageType.Close });
        this.mergeFieldDropdownStream.next({ type: SkyDropdownMessageType.Close });
    }
    #clearFormat() {
        const currentSelection = this.#adapterService.getCurrentSelection();
        /* istanbul ignore else */
        if (currentSelection &&
            currentSelection.rangeCount > 0 &&
            currentSelection.getRangeAt(0).toString().length <= 0) {
            this.execCommand('selectAll');
        }
        this.execCommand('removeFormat');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorMenubarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkyTextEditorMenubarComponent, isStandalone: true, selector: "sky-text-editor-menubar", inputs: { editorFocusStream: "editorFocusStream", menus: "menus", mergeFields: "mergeFields", disabled: ["disabled", "disabled", booleanAttribute] }, ngImport: i0, template: "@for (menu of menus; track menu) {\n  <sky-toolbar-item\n    class=\"sky-text-editor-menu\"\n    [ngClass]=\"'sky-text-editor-menu-' + menu\"\n  >\n    @switch (menu) {\n      @case ('edit') {\n        <sky-dropdown\n          label=\"Edit menu\"\n          [disabled]=\"disabled\"\n          [messageStream]=\"editDropdownStream\"\n        >\n          <sky-dropdown-button>\n            {{\n              'skyux_text_editor_menubar_dropdown_button_edit_label'\n                | skyLibResources\n            }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (editItem of editItems; track editItem) {\n              <sky-dropdown-item>\n                @if (!editItem.isDivider) {\n                  <button type=\"button\" (click)=\"editItem?.function?.()\">\n                    {{ editItem.label }}\n                    @if (editItem.keyShortcut) {\n                      <div\n                        class=\"sky-text-editor-menu-key-shortcut\"\n                        [skyThemeClass]=\"{\n                          'sky-font-deemphasized': 'modern',\n                          'sky-deemphasized': 'default'\n                        }\"\n                      >\n                        {{ editItem.keyShortcut }}\n                      </div>\n                    }\n                  </button>\n                } @else {\n                  <div\n                    class=\"sky-text-editor-dropdown-item-divider\"\n                    role=\"divider\"\n                  ></div>\n                }\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('format') {\n        <sky-dropdown\n          label=\"Format menu\"\n          [disabled]=\"disabled\"\n          [messageStream]=\"formatDropdownStream\"\n        >\n          <sky-dropdown-button>\n            {{\n              'skyux_text_editor_menubar_dropdown_button_format_label'\n                | skyLibResources\n            }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (formatItem of formatItems; track formatItem) {\n              <sky-dropdown-item>\n                @if (!formatItem.isDivider) {\n                  <button type=\"button\" (click)=\"formatItem?.function?.()\">\n                    {{ formatItem.label }}\n                    @if (formatItem.keyShortcut) {\n                      <div\n                        class=\"sky-text-editor-menu-key-shortcut\"\n                        [skyThemeClass]=\"{\n                          'sky-font-deemphasized': 'modern',\n                          'sky-deemphasized': 'default'\n                        }\"\n                      >\n                        {{ formatItem.keyShortcut }}\n                      </div>\n                    }\n                  </button>\n                } @else {\n                  <div\n                    class=\"sky-text-editor-dropdown-item-divider\"\n                    role=\"divider\"\n                  ></div>\n                }\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('merge-field') {\n        @if (mergeFields && mergeFields.length > 0) {\n          <sky-dropdown\n            label=\"Insert merge field\"\n            [disabled]=\"disabled\"\n            [messageStream]=\"mergeFieldDropdownStream\"\n          >\n            <sky-dropdown-button>\n              {{\n                'skyux_text_editor_menubar_dropdown_button_insert_label'\n                  | skyLibResources\n              }}\n            </sky-dropdown-button>\n            <sky-dropdown-menu>\n              @for (mergeField of mergeFields; track mergeField.name) {\n                <sky-dropdown-item>\n                  <button type=\"button\" (click)=\"insertMergeField(mergeField)\">\n                    {{ mergeField.name }}\n                  </button>\n                </sky-dropdown-item>\n              }\n            </sky-dropdown-menu>\n          </sky-dropdown>\n        }\n      }\n    }\n  </sky-toolbar-item>\n}\n", styles: [".sky-text-editor-dropdown-item-divider{border:0;padding:0;height:1px;margin:9px 1px;overflow:hidden;background:transparent;border-bottom:1px solid rgba(0,0,0,.1);cursor:default;filter:none}.sky-text-editor-menu-key-shortcut{float:right;margin-left:15px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: SkyDropdownModule }, { kind: "component", type: i2.λ2, selector: "sky-dropdown-button" }, { kind: "component", type: i2.λ3, selector: "sky-dropdown", inputs: ["buttonStyle", "buttonType", "disabled", "label", "horizontalAlignment", "messageStream", "title", "trigger"] }, { kind: "component", type: i2.λ1, selector: "sky-dropdown-item", inputs: ["ariaRole"] }, { kind: "component", type: i2.λ4, selector: "sky-dropdown-menu", inputs: ["ariaLabelledBy", "ariaRole", "useNativeFocus"], outputs: ["menuChanges"] }, { kind: "ngmodule", type: SkyTextEditorResourcesModule }, { kind: "pipe", type: i3$1.SkyLibResourcesPipe, name: "skyLibResources" }, { kind: "ngmodule", type: SkyThemeModule }, { kind: "directive", type: i4.λ2, selector: "[skyThemeClass]", inputs: ["class", "skyThemeClass"] }, { kind: "ngmodule", type: SkyToolbarModule }, { kind: "component", type: i6.λ39, selector: "sky-toolbar-item" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorMenubarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sky-text-editor-menubar', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        CommonModule,
                        SkyDropdownModule,
                        SkyTextEditorResourcesModule,
                        SkyThemeModule,
                        SkyToolbarModule,
                    ], template: "@for (menu of menus; track menu) {\n  <sky-toolbar-item\n    class=\"sky-text-editor-menu\"\n    [ngClass]=\"'sky-text-editor-menu-' + menu\"\n  >\n    @switch (menu) {\n      @case ('edit') {\n        <sky-dropdown\n          label=\"Edit menu\"\n          [disabled]=\"disabled\"\n          [messageStream]=\"editDropdownStream\"\n        >\n          <sky-dropdown-button>\n            {{\n              'skyux_text_editor_menubar_dropdown_button_edit_label'\n                | skyLibResources\n            }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (editItem of editItems; track editItem) {\n              <sky-dropdown-item>\n                @if (!editItem.isDivider) {\n                  <button type=\"button\" (click)=\"editItem?.function?.()\">\n                    {{ editItem.label }}\n                    @if (editItem.keyShortcut) {\n                      <div\n                        class=\"sky-text-editor-menu-key-shortcut\"\n                        [skyThemeClass]=\"{\n                          'sky-font-deemphasized': 'modern',\n                          'sky-deemphasized': 'default'\n                        }\"\n                      >\n                        {{ editItem.keyShortcut }}\n                      </div>\n                    }\n                  </button>\n                } @else {\n                  <div\n                    class=\"sky-text-editor-dropdown-item-divider\"\n                    role=\"divider\"\n                  ></div>\n                }\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('format') {\n        <sky-dropdown\n          label=\"Format menu\"\n          [disabled]=\"disabled\"\n          [messageStream]=\"formatDropdownStream\"\n        >\n          <sky-dropdown-button>\n            {{\n              'skyux_text_editor_menubar_dropdown_button_format_label'\n                | skyLibResources\n            }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (formatItem of formatItems; track formatItem) {\n              <sky-dropdown-item>\n                @if (!formatItem.isDivider) {\n                  <button type=\"button\" (click)=\"formatItem?.function?.()\">\n                    {{ formatItem.label }}\n                    @if (formatItem.keyShortcut) {\n                      <div\n                        class=\"sky-text-editor-menu-key-shortcut\"\n                        [skyThemeClass]=\"{\n                          'sky-font-deemphasized': 'modern',\n                          'sky-deemphasized': 'default'\n                        }\"\n                      >\n                        {{ formatItem.keyShortcut }}\n                      </div>\n                    }\n                  </button>\n                } @else {\n                  <div\n                    class=\"sky-text-editor-dropdown-item-divider\"\n                    role=\"divider\"\n                  ></div>\n                }\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('merge-field') {\n        @if (mergeFields && mergeFields.length > 0) {\n          <sky-dropdown\n            label=\"Insert merge field\"\n            [disabled]=\"disabled\"\n            [messageStream]=\"mergeFieldDropdownStream\"\n          >\n            <sky-dropdown-button>\n              {{\n                'skyux_text_editor_menubar_dropdown_button_insert_label'\n                  | skyLibResources\n              }}\n            </sky-dropdown-button>\n            <sky-dropdown-menu>\n              @for (mergeField of mergeFields; track mergeField.name) {\n                <sky-dropdown-item>\n                  <button type=\"button\" (click)=\"insertMergeField(mergeField)\">\n                    {{ mergeField.name }}\n                  </button>\n                </sky-dropdown-item>\n              }\n            </sky-dropdown-menu>\n          </sky-dropdown>\n        }\n      }\n    }\n  </sky-toolbar-item>\n}\n", styles: [".sky-text-editor-dropdown-item-divider{border:0;padding:0;height:1px;margin:9px 1px;overflow:hidden;background:transparent;border-bottom:1px solid rgba(0,0,0,.1);cursor:default;filter:none}.sky-text-editor-menu-key-shortcut{float:right;margin-left:15px}\n"] }]
        }], propDecorators: { editorFocusStream: [{
                type: Input
            }], menus: [{
                type: Input
            }], mergeFields: [{
                type: Input
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * @internal
 */
class SkyUrlModalContext {
}

const emailKey = 'mailto:';
const queryStringParamKey = '?Subject=';
/**
 * @internal
 */
class SkyTextEditorUrlModalComponent {
    set activeTab(value) {
        this.#_activeTab = value;
        this.valid = this.#isValid();
    }
    get activeTab() {
        return this.#_activeTab;
    }
    set emailAddress(value) {
        this.#_emailAddress = value;
        this.valid = this.#isValid();
    }
    get emailAddress() {
        return this.#_emailAddress;
    }
    set url(value) {
        this.#_url = value;
        this.valid = this.#isValid();
    }
    get url() {
        return this.#_url;
    }
    #_activeTab;
    #_emailAddress;
    #_url;
    #modalContext;
    #modalInstance;
    constructor() {
        this.emailAddressValid = false;
        this.allowAllOpenLinkOptions = true;
        this.openLinksInNewWindowOnly = false;
        this.subject = '';
        this.target = 0;
        this.valid = false;
        this.#_activeTab = 0;
        this.#_emailAddress = '';
        this.#_url = 'https://';
        this.#modalContext = inject(SkyUrlModalContext);
        this.#modalInstance = inject(SkyModalInstance);
        const linkWindowOptions = this.#modalContext.linkWindowOptions;
        if (linkWindowOptions?.length === 1) {
            this.allowAllOpenLinkOptions = false;
            if (linkWindowOptions[0] === 'new') {
                this.openLinksInNewWindowOnly = true;
                this.target = 1;
            }
            else {
                this.target = 0;
            }
        }
        if (this.#modalContext.urlResult) {
            if (this.#modalContext.urlResult.url.startsWith(emailKey)) {
                this.emailAddress = this.#modalContext.urlResult.url.replace(emailKey, '');
                let queryStringIndex = this.emailAddress.indexOf(queryStringParamKey);
                queryStringIndex =
                    queryStringIndex > -1
                        ? queryStringIndex
                        : this.emailAddress.indexOf(queryStringParamKey.toLowerCase());
                /* istanbul ignore else */
                if (queryStringIndex > -1) {
                    this.subject = decodeURI(this.emailAddress).slice(queryStringIndex + queryStringParamKey.length);
                    this.emailAddress = this.emailAddress.slice(0, queryStringIndex);
                }
                // Set active tab to email
                this.activeTab = 1;
            }
            else {
                this.url = this.#modalContext.urlResult.url;
                this.target = this.#modalContext.urlResult.target;
                // set active tab to web page
                this.activeTab = 0;
            }
        }
    }
    activeTabChanged(value) {
        this.activeTab = Number(value);
    }
    save() {
        /* istanbul ignore else */
        if (this.#isValid()) {
            if (this.activeTab === 0) {
                this.#modalInstance.save({
                    url: this.url,
                    target: this.target
                        ? parseInt(this.target, undefined)
                        : UrlTarget.None,
                });
            }
            else {
                this.#modalInstance.save({
                    url: this.#getEmailUrl(),
                    target: UrlTarget.None,
                });
            }
        }
    }
    cancel() {
        this.#modalInstance.cancel();
    }
    #getEmailUrl() {
        return (emailKey +
            this.emailAddress +
            (this.subject ? '?Subject=' + encodeURI(this.subject) : ''));
    }
    #isValid() {
        if (this.activeTab === 0) {
            return !!this.url && SkyValidation.isUrl(this.url);
        }
        return !!this.emailAddress && SkyValidation.isEmail(this.emailAddress);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorUrlModalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkyTextEditorUrlModalComponent, isStandalone: true, selector: "sky-text-editor-url-modal", ngImport: i0, template: "<sky-modal>\n  <sky-modal-header>\n    {{ 'skyux_text_editor_url_modal_header_label' | skyLibResources }}\n  </sky-modal-header>\n  <sky-modal-content>\n    <sky-tabset\n      data-sky-id=\"test-tabset\"\n      [active]=\"activeTab\"\n      (activeChange)=\"activeTabChanged($event)\"\n    >\n      <sky-tab tabHeading=\"Web page\">\n        <div class=\"sky-form-group sky-text-editor-url-modal-first-field\">\n          <sky-input-box\n            class=\"sky-text-editor-url-input\"\n            stacked=\"true\"\n            [hintText]=\"\n              openLinksInNewWindowOnly\n                ? ('skyux_text_editor_url_modal_open_in_new_window_label'\n                  | skyLibResources)\n                : undefined\n            \"\n          >\n            <label\n              class=\"sky-control-label sky-control-label-required\"\n              [for]=\"urlInput.id\"\n            >\n              {{ 'skyux_text_editor_url_modal_url_label' | skyLibResources }}\n            </label>\n            <input\n              #urlInput=\"skyId\"\n              class=\"sky-form-control\"\n              type=\"text\"\n              skyId\n              [(ngModel)]=\"url\"\n            />\n          </sky-input-box>\n        </div>\n        @if (allowAllOpenLinkOptions) {\n          <sky-input-box stacked=\"true\" class=\"sky-form-group\">\n            <label class=\"sky-control-label\" [for]=\"targetInput.id\">\n              {{ 'skyux_text_editor_url_modal_open_label' | skyLibResources }}\n            </label>\n            <select\n              #targetInput=\"skyId\"\n              class=\"sky-form-control\"\n              skyId\n              [(ngModel)]=\"target\"\n            >\n              <option value=\"0\">\n                {{\n                  'skyux_text_editor_url_modal_current_option_label'\n                    | skyLibResources\n                }}\n              </option>\n              <option value=\"1\">\n                {{\n                  'skyux_text_editor_url_modal_new_option_label'\n                    | skyLibResources\n                }}\n              </option>\n            </select>\n          </sky-input-box>\n        }\n      </sky-tab>\n      <sky-tab tabHeading=\"Email address\">\n        <div class=\"sky-form-group first-field\">\n          <sky-input-box stacked=\"true\">\n            <label\n              class=\"sky-control-label sky-control-label-required\"\n              [for]=\"emailAddressInput.id\"\n            >\n              {{ 'skyux_text_editor_url_modal_email_label' | skyLibResources }}\n            </label>\n            <input\n              #emailAddressInput=\"skyId\"\n              class=\"sky-form-control\"\n              type=\"text\"\n              skyId\n              [(ngModel)]=\"emailAddress\"\n            />\n          </sky-input-box>\n        </div>\n        <sky-input-box stacked=\"true\" class=\"sky-form-group\">\n          <label class=\"sky-control-label\" [for]=\"subjectInput.id\">\n            {{ 'skyux_text_editor_url_modal_subject_label' | skyLibResources }}\n          </label>\n          <input\n            #subjectInput=\"skyId\"\n            class=\"sky-form-control\"\n            type=\"text\"\n            skyId\n            [(ngModel)]=\"subject\"\n          />\n        </sky-input-box>\n      </sky-tab>\n    </sky-tabset>\n  </sky-modal-content>\n  <sky-modal-footer>\n    <button\n      type=\"submit\"\n      class=\"sky-btn sky-btn-primary\"\n      [disabled]=\"!valid\"\n      (click)=\"save()\"\n    >\n      {{ 'skyux_text_editor_url_modal_save_button_label' | skyLibResources }}\n    </button>\n    <button type=\"button\" class=\"sky-btn sky-btn-link\" (click)=\"cancel()\">\n      {{ 'skyux_text_editor_url_modal_cancel_button_label' | skyLibResources }}\n    </button>\n  </sky-modal-footer>\n</sky-modal>\n", styles: [".sky-text-editor-url-modal-first-field{margin-top:15px}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: SkyModalModule }, { kind: "component", type: i2$1.λ5, selector: "sky-modal", inputs: ["formErrors", "headingText", "helpKey", "helpPopoverContent", "helpPopoverTitle", "ariaRole", "tiledBody", "ariaDescribedBy", "ariaLabelledBy", "layout"] }, { kind: "component", type: i2$1.λ2, selector: "sky-modal-content" }, { kind: "component", type: i2$1.λ3, selector: "sky-modal-footer" }, { kind: "component", type: i2$1.λ4, selector: "sky-modal-header" }, { kind: "ngmodule", type: SkyIdModule }, { kind: "directive", type: i3.λ2, selector: "[skyId]", exportAs: ["skyId"] }, { kind: "ngmodule", type: SkyInputBoxModule }, { kind: "component", type: i1$3.λ10, selector: "sky-input-box", inputs: ["hasErrors", "disabled", "labelText", "characterLimit", "stacked", "helpPopoverTitle", "helpPopoverContent", "helpKey", "hintText"] }, { kind: "ngmodule", type: SkyTabsModule }, { kind: "component", type: i5.λ1, selector: "sky-tab", inputs: ["active", "disabled", "permalinkValue", "tabHeaderCount", "tabHeading", "tabIndexValue", "layout"], outputs: ["close"] }, { kind: "component", type: i5.λ2, selector: "sky-tabset", inputs: ["active", "ariaLabel", "ariaLabelledBy", "permalinkId", "tabStyle"], outputs: ["activeChange", "newTab", "openTab", "tabIndexesChange"] }, { kind: "ngmodule", type: SkyTextEditorResourcesModule }, { kind: "pipe", type: i3$1.SkyLibResourcesPipe, name: "skyLibResources" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorUrlModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sky-text-editor-url-modal', imports: [
                        FormsModule,
                        SkyModalModule,
                        SkyIdModule,
                        SkyInputBoxModule,
                        SkyTabsModule,
                        SkyTextEditorResourcesModule,
                    ], template: "<sky-modal>\n  <sky-modal-header>\n    {{ 'skyux_text_editor_url_modal_header_label' | skyLibResources }}\n  </sky-modal-header>\n  <sky-modal-content>\n    <sky-tabset\n      data-sky-id=\"test-tabset\"\n      [active]=\"activeTab\"\n      (activeChange)=\"activeTabChanged($event)\"\n    >\n      <sky-tab tabHeading=\"Web page\">\n        <div class=\"sky-form-group sky-text-editor-url-modal-first-field\">\n          <sky-input-box\n            class=\"sky-text-editor-url-input\"\n            stacked=\"true\"\n            [hintText]=\"\n              openLinksInNewWindowOnly\n                ? ('skyux_text_editor_url_modal_open_in_new_window_label'\n                  | skyLibResources)\n                : undefined\n            \"\n          >\n            <label\n              class=\"sky-control-label sky-control-label-required\"\n              [for]=\"urlInput.id\"\n            >\n              {{ 'skyux_text_editor_url_modal_url_label' | skyLibResources }}\n            </label>\n            <input\n              #urlInput=\"skyId\"\n              class=\"sky-form-control\"\n              type=\"text\"\n              skyId\n              [(ngModel)]=\"url\"\n            />\n          </sky-input-box>\n        </div>\n        @if (allowAllOpenLinkOptions) {\n          <sky-input-box stacked=\"true\" class=\"sky-form-group\">\n            <label class=\"sky-control-label\" [for]=\"targetInput.id\">\n              {{ 'skyux_text_editor_url_modal_open_label' | skyLibResources }}\n            </label>\n            <select\n              #targetInput=\"skyId\"\n              class=\"sky-form-control\"\n              skyId\n              [(ngModel)]=\"target\"\n            >\n              <option value=\"0\">\n                {{\n                  'skyux_text_editor_url_modal_current_option_label'\n                    | skyLibResources\n                }}\n              </option>\n              <option value=\"1\">\n                {{\n                  'skyux_text_editor_url_modal_new_option_label'\n                    | skyLibResources\n                }}\n              </option>\n            </select>\n          </sky-input-box>\n        }\n      </sky-tab>\n      <sky-tab tabHeading=\"Email address\">\n        <div class=\"sky-form-group first-field\">\n          <sky-input-box stacked=\"true\">\n            <label\n              class=\"sky-control-label sky-control-label-required\"\n              [for]=\"emailAddressInput.id\"\n            >\n              {{ 'skyux_text_editor_url_modal_email_label' | skyLibResources }}\n            </label>\n            <input\n              #emailAddressInput=\"skyId\"\n              class=\"sky-form-control\"\n              type=\"text\"\n              skyId\n              [(ngModel)]=\"emailAddress\"\n            />\n          </sky-input-box>\n        </div>\n        <sky-input-box stacked=\"true\" class=\"sky-form-group\">\n          <label class=\"sky-control-label\" [for]=\"subjectInput.id\">\n            {{ 'skyux_text_editor_url_modal_subject_label' | skyLibResources }}\n          </label>\n          <input\n            #subjectInput=\"skyId\"\n            class=\"sky-form-control\"\n            type=\"text\"\n            skyId\n            [(ngModel)]=\"subject\"\n          />\n        </sky-input-box>\n      </sky-tab>\n    </sky-tabset>\n  </sky-modal-content>\n  <sky-modal-footer>\n    <button\n      type=\"submit\"\n      class=\"sky-btn sky-btn-primary\"\n      [disabled]=\"!valid\"\n      (click)=\"save()\"\n    >\n      {{ 'skyux_text_editor_url_modal_save_button_label' | skyLibResources }}\n    </button>\n    <button type=\"button\" class=\"sky-btn sky-btn-link\" (click)=\"cancel()\">\n      {{ 'skyux_text_editor_url_modal_cancel_button_label' | skyLibResources }}\n    </button>\n  </sky-modal-footer>\n</sky-modal>\n", styles: [".sky-text-editor-url-modal-first-field{margin-top:15px}\n"] }]
        }], ctorParameters: () => [] });

/**
 * @internal
 */
class SkyTextEditorToolbarComponent {
    constructor() {
        this.fontList = [];
        this.fontSizeList = [];
        this.toolbarActions = [];
        this.linkWindowOptions = [];
        this.disabled = false;
        this.backColorpickerStream = new Subject();
        this.colorpickerStream = new Subject();
        this.fontPickerStream = new Subject();
        this.fontSizeStream = new Subject();
        this.#ngUnsubscribe = new Subject();
        this.#_editorFocusStream = new Subject();
        this.#_styleState = STYLE_STATE_DEFAULTS;
        this.#adapterService = inject(SkyTextEditorAdapterService);
        this.#changeDetector = inject(ChangeDetectorRef);
        this.#modalService = inject(SkyModalService);
    }
    set editorFocusStream(value) {
        this.#_editorFocusStream = value;
        this.#subscribeEditorFocus();
    }
    get editorFocusStream() {
        return this.#_editorFocusStream;
    }
    set styleState(value) {
        this.#_styleState = value;
        if (value.font !== this.styleStateFontName) {
            if (value.font === '"Blackbaud Sans", Arial, sans-serif') {
                this.styleStateFontName = this.#getFontName('Blackbaud Sans');
            }
            else {
                this.styleStateFontName = this.#getFontName(value.font);
            }
        }
    }
    get styleState() {
        return this.#_styleState;
    }
    #editorFocusStreamSub;
    #ngUnsubscribe;
    #_editorFocusStream;
    #_styleState;
    #adapterService;
    #changeDetector;
    #modalService;
    ngOnInit() {
        this.#subscribeEditorFocus();
    }
    execCommand(command, value = '') {
        void this.#adapterService.execCommand({
            command: command,
            value: value,
        });
        this.styleState = {
            ...this.styleState,
            ...this.#adapterService.getStyleState(),
        };
    }
    toggleFontStyle(currentState, newState, command) {
        if (currentState !== newState) {
            this.execCommand(command);
        }
        // Force sky-checkbox to show changes on user's initial click.
        this.#changeDetector.detectChanges();
    }
    link() {
        const priorSelection = this.#adapterService.saveSelection();
        const currentLink = this.#adapterService.getLink();
        const inputModal = this.#modalService.open(SkyTextEditorUrlModalComponent, [
            {
                provide: SkyUrlModalContext,
                useFactory: () => {
                    const context = new SkyUrlModalContext();
                    context.urlResult = currentLink;
                    context.linkWindowOptions = this.linkWindowOptions;
                    return context;
                },
            },
        ]);
        inputModal.closed.subscribe((result) => {
            if (result.reason === 'save' && priorSelection) {
                if (currentLink) {
                    const anchor = this.#adapterService.getSelectedAnchorTag();
                    if (anchor) {
                        this.#adapterService.selectElement(anchor);
                    }
                }
                this.execCommand('unlink');
                if (result.data.target === UrlTarget.None) {
                    // Current window
                    this.execCommand('createLink', result.data.url);
                }
                else {
                    // New Window
                    const sText = this.#adapterService.getCurrentSelection();
                    this.execCommand('insertHTML', '<a href="' +
                        result.data.url +
                        '" rel="noopener noreferrer" target="_blank">' +
                        sText +
                        '</a>');
                }
            }
        });
    }
    unlink() {
        const currentSelectionRange = this.#adapterService
            .getCurrentSelection()
            ?.getRangeAt(0);
        if (currentSelectionRange && currentSelectionRange.toString().length <= 0) {
            const anchorTag = this.#adapterService.getSelectedAnchorTag();
            if (anchorTag) {
                this.#adapterService.selectElement(anchorTag);
            }
        }
        this.execCommand('unlink');
    }
    changeFontSize(size) {
        void this.#adapterService.setFontSize(size);
        this.styleState = {
            ...this.styleState,
            ...this.#adapterService.getStyleState(),
        };
    }
    onColorpickerColorChanged(color, isBackground = false) {
        if (isBackground) {
            this.execCommand('backColor', color.rgbaText);
        }
        else {
            this.execCommand('foreColor', color.hex);
        }
    }
    #subscribeEditorFocus() {
        this.#editorFocusStreamSub?.unsubscribe();
        this.#editorFocusStreamSub = this.editorFocusStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.styleState = {
                ...this.styleState,
                ...this.#adapterService.getStyleState(),
            };
            this.#closeDropdowns();
            this.#changeDetector.detectChanges();
        });
    }
    #closeDropdowns() {
        const message = {
            type: SkyColorpickerMessageType.Close,
        };
        this.colorpickerStream.next(message);
        this.backColorpickerStream.next(message);
        this.fontPickerStream.next({ type: SkyDropdownMessageType.Close });
        this.fontSizeStream.next({ type: SkyDropdownMessageType.Close });
    }
    #getFontName(fontName) {
        for (const skyTextEditorFont of this.fontList) {
            if (fontName.replace(/['"]+/g, '') === skyTextEditorFont.name) {
                return skyTextEditorFont.name;
            }
        }
        /* istanbul ignore next */
        return undefined;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkyTextEditorToolbarComponent, isStandalone: true, selector: "sky-text-editor-toolbar", inputs: { editorFocusStream: "editorFocusStream", fontList: "fontList", fontSizeList: "fontSizeList", toolbarActions: "toolbarActions", linkWindowOptions: "linkWindowOptions", styleState: "styleState", disabled: ["disabled", "disabled", booleanAttribute] }, ngImport: i0, template: "@for (action of toolbarActions; track action) {\n  <sky-toolbar-item\n    class=\"sky-text-editor-toolbar-action\"\n    [ngClass]=\"'sky-text-editor-toolbar-action-' + action\"\n  >\n    @switch (action) {\n      @case ('font-family') {\n        <sky-dropdown\n          class=\"sky-text-editor-font-picker\"\n          [disabled]=\"disabled\"\n          [label]=\"'Font: ' + styleStateFontName\"\n          [messageStream]=\"fontPickerStream\"\n        >\n          <sky-dropdown-button\n            [ngStyle]=\"{\n              'font-family': styleState.font\n            }\"\n          >\n            {{ styleStateFontName }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (fontModel of fontList; track fontModel.name) {\n              <sky-dropdown-item>\n                <button\n                  type=\"button\"\n                  [ngStyle]=\"{\n                    'font-family': fontModel.value\n                  }\"\n                  (click)=\"execCommand('fontname', fontModel.name)\"\n                >\n                  {{ fontModel.name }}\n                </button>\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('font-size') {\n        <sky-dropdown\n          class=\"sky-text-editor-font-size-picker\"\n          [disabled]=\"disabled\"\n          [label]=\"'Font size: ' + styleState.fontSize + 'px'\"\n          [messageStream]=\"fontSizeStream\"\n        >\n          <sky-dropdown-button\n            [ngStyle]=\"{\n              'font-family': styleState.fontSize\n            }\"\n          >\n            {{ styleState.fontSize + 'px' }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (size of fontSizeList; track size) {\n              <sky-dropdown-item>\n                <button type=\"button\" (click)=\"changeFontSize(size)\">\n                  {{ size + 'px' }}\n                </button>\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('font-style') {\n        <div class=\"sky-switch-icon-group sky-text-editor-font-style-picker\">\n          <sky-checkbox\n            iconName=\"text-bold\"\n            label=\"Bold\"\n            title=\"Bold\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.boldState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.boldState, $event, 'bold')\n            \"\n          />\n          <sky-checkbox\n            iconName=\"text-italic\"\n            label=\"Italicized\"\n            title=\"Italicized\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.italicState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.italicState, $event, 'italic')\n            \"\n          />\n          <sky-checkbox\n            iconName=\"text-underline\"\n            label=\"Underline\"\n            title=\"Underline\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.underlineState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.underlineState, $event, 'underline')\n            \"\n          />\n        </div>\n      }\n      @case ('color') {\n        <div class=\"sky-text-editor-colorpicker-group\">\n          <div class=\"sky-text-editor-colorpicker-container\">\n            <sky-colorpicker\n              #colorPicker\n              class=\"sky-text-editor-font-color-picker\"\n              label=\"Font color\"\n              pickerButtonIcon=\"color-line\"\n              [messageStream]=\"colorpickerStream\"\n              [showResetButton]=\"false\"\n              (selectedColorChanged)=\"onColorpickerColorChanged($event)\"\n            >\n              <input\n                outputFormat=\"hex\"\n                type=\"text\"\n                [allowTransparency]=\"false\"\n                [disabled]=\"disabled\"\n                [ngModel]=\"styleState.fontColor\"\n                [skyColorpickerInput]=\"colorPicker\"\n              />\n            </sky-colorpicker>\n          </div>\n          <div class=\"sky-text-editor-colorpicker-container\">\n            <sky-colorpicker\n              #backColorPicker\n              class=\"sky-text-editor-background-color-picker\"\n              label=\"Background color\"\n              pickerButtonIcon=\"text-color\"\n              [messageStream]=\"backColorpickerStream\"\n              [showResetButton]=\"false\"\n              (selectedColorChanged)=\"onColorpickerColorChanged($event, true)\"\n            >\n              <input\n                outputFormat=\"rgba\"\n                type=\"text\"\n                [allowTransparency]=\"true\"\n                [disabled]=\"disabled\"\n                [ngModel]=\"styleState.backColor\"\n                [skyColorpickerInput]=\"backColorPicker\"\n              />\n            </sky-colorpicker>\n          </div>\n        </div>\n      }\n      @case ('list') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Bulleted list\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Bulleted list\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('insertUnorderedList')\"\n          >\n            <sky-icon iconName=\"text-bullet-list\" />\n          </button>\n          <button\n            aria-label=\"Numbered list\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Numbered list\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('insertOrderedList')\"\n          >\n            <sky-icon iconName=\"text-number-list-ltr\" />\n          </button>\n        </div>\n      }\n      @case ('alignment') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Align left\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align left\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyLeft')\"\n          >\n            <sky-icon iconName=\"text-align-left\" />\n          </button>\n          <button\n            aria-label=\"Align center\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align center\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyCenter')\"\n          >\n            <sky-icon iconName=\"text-align-center\" />\n          </button>\n          <button\n            aria-label=\"Align right\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align right\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyRight')\"\n          >\n            <sky-icon iconName=\"text-align-right\" />\n          </button>\n        </div>\n      }\n      @case ('indentation') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Outdent\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Outdent\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('outdent')\"\n          >\n            <sky-icon iconName=\"text-indent-decrease\" />\n          </button>\n          <button\n            aria-label=\"Indent\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Indent\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('indent')\"\n          >\n            <sky-icon iconName=\"text-indent-increase\" />\n          </button>\n        </div>\n      }\n      @case ('undo-redo') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Undo\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Undo\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('undo')\"\n          >\n            <sky-icon iconName=\"arrow-undo\" />\n          </button>\n          <button\n            aria-label=\"Redo\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Redo\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('redo')\"\n          >\n            <sky-icon iconName=\"arrow-redo\" />\n          </button>\n        </div>\n      }\n      @case ('link') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Link\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Link\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            [ngClass]=\"{\n              'icon-btn-active': styleState.linkState\n            }\"\n            (click)=\"link()\"\n          >\n            <sky-icon iconName=\"link\" />\n          </button>\n          <button\n            aria-label=\"Unlink\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Unlink\"\n            type=\"button\"\n            [disabled]=\"!styleState.linkState || disabled\"\n            (click)=\"unlink()\"\n          >\n            <sky-icon iconName=\"link-dismiss\" />\n          </button>\n        </div>\n      }\n    }\n  </sky-toolbar-item>\n}\n", styles: [".sky-text-editor-toolbar-action:not(.sky-theme-modern *){--sky-override-text-editor-border-radius: 0;--sky-override-text-editor-button-border-outer-radius: 3px;--sky-override-text-editor-button-border: 1px solid #cdcfd2;--sky-override-text-editor-colorpicker-spacing: 10px;--sky-override-text-editor-colorpicker-top: 3px}.sky-text-editor-toolbar-action .sky-text-editor-font-picker ::ng-deep .sky-dropdown-button-content-container{width:140px;height:20px;text-align:left}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group{display:flex}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group .sky-text-editor-colorpicker-container{position:relative;top:var(--sky-override-text-editor-colorpicker-top, -2px);margin-right:var(--sky-override-text-editor-colorpicker-spacing, var(--sky-space-gap-action_group-m))}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group .sky-text-editor-colorpicker-container:last-child{margin-right:0}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn{margin-left:0;margin-right:0;border-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-right:none}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn:first-of-type{border-top-left-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-bottom-left-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s))}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn:last-of-type{border-top-right-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-bottom-right-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-right:var(--sky-override-text-editor-button-border, none)}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: SkyCheckboxModule }, { kind: "component", type: i1$3.λ3, selector: "sky-checkbox", inputs: ["label", "labelledBy", "id", "disabled", "tabindex", "name", "helpPopoverContent", "helpPopoverTitle", "icon", "iconName", "checkboxType", "checked", "indeterminate", "required", "labelText", "labelHidden", "hintText", "stacked", "helpKey"], outputs: ["change", "checkedChange", "disabledChange", "indeterminateChange"] }, { kind: "ngmodule", type: SkyColorpickerModule }, { kind: "component", type: i4$1.λ1, selector: "sky-colorpicker", inputs: ["pickerButtonIcon", "label", "labelledBy", "labelText", "labelHidden", "helpKey", "helpPopoverContent", "helpPopoverTitle", "hintText", "stacked", "messageStream", "showResetButton"], outputs: ["selectedColorChanged", "selectedColorApplied"] }, { kind: "directive", type: i4$1.λ2, selector: "[skyColorpickerInput]", inputs: ["skyColorpickerInput", "initialColor", "id", "returnFormat", "outputFormat", "presetColors", "alphaChannel", "allowTransparency"] }, { kind: "ngmodule", type: SkyDropdownModule }, { kind: "component", type: i2.λ2, selector: "sky-dropdown-button" }, { kind: "component", type: i2.λ3, selector: "sky-dropdown", inputs: ["buttonStyle", "buttonType", "disabled", "label", "horizontalAlignment", "messageStream", "title", "trigger"] }, { kind: "component", type: i2.λ1, selector: "sky-dropdown-item", inputs: ["ariaRole"] }, { kind: "component", type: i2.λ4, selector: "sky-dropdown-menu", inputs: ["ariaLabelledBy", "ariaRole", "useNativeFocus"], outputs: ["menuChanges"] }, { kind: "ngmodule", type: SkyIconModule }, { kind: "component", type: i6$1.λ1, selector: "sky-icon", inputs: ["icon", "iconName", "iconType", "size", "fixedWidth", "variant", "iconSize"] }, { kind: "ngmodule", type: SkyThemeModule }, { kind: "ngmodule", type: SkyToolbarModule }, { kind: "component", type: i6.λ39, selector: "sky-toolbar-item" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sky-text-editor-toolbar', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        CommonModule,
                        FormsModule,
                        SkyCheckboxModule,
                        SkyColorpickerModule,
                        SkyDropdownModule,
                        SkyIconModule,
                        SkyThemeModule,
                        SkyToolbarModule,
                    ], template: "@for (action of toolbarActions; track action) {\n  <sky-toolbar-item\n    class=\"sky-text-editor-toolbar-action\"\n    [ngClass]=\"'sky-text-editor-toolbar-action-' + action\"\n  >\n    @switch (action) {\n      @case ('font-family') {\n        <sky-dropdown\n          class=\"sky-text-editor-font-picker\"\n          [disabled]=\"disabled\"\n          [label]=\"'Font: ' + styleStateFontName\"\n          [messageStream]=\"fontPickerStream\"\n        >\n          <sky-dropdown-button\n            [ngStyle]=\"{\n              'font-family': styleState.font\n            }\"\n          >\n            {{ styleStateFontName }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (fontModel of fontList; track fontModel.name) {\n              <sky-dropdown-item>\n                <button\n                  type=\"button\"\n                  [ngStyle]=\"{\n                    'font-family': fontModel.value\n                  }\"\n                  (click)=\"execCommand('fontname', fontModel.name)\"\n                >\n                  {{ fontModel.name }}\n                </button>\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('font-size') {\n        <sky-dropdown\n          class=\"sky-text-editor-font-size-picker\"\n          [disabled]=\"disabled\"\n          [label]=\"'Font size: ' + styleState.fontSize + 'px'\"\n          [messageStream]=\"fontSizeStream\"\n        >\n          <sky-dropdown-button\n            [ngStyle]=\"{\n              'font-family': styleState.fontSize\n            }\"\n          >\n            {{ styleState.fontSize + 'px' }}\n          </sky-dropdown-button>\n          <sky-dropdown-menu>\n            @for (size of fontSizeList; track size) {\n              <sky-dropdown-item>\n                <button type=\"button\" (click)=\"changeFontSize(size)\">\n                  {{ size + 'px' }}\n                </button>\n              </sky-dropdown-item>\n            }\n          </sky-dropdown-menu>\n        </sky-dropdown>\n      }\n      @case ('font-style') {\n        <div class=\"sky-switch-icon-group sky-text-editor-font-style-picker\">\n          <sky-checkbox\n            iconName=\"text-bold\"\n            label=\"Bold\"\n            title=\"Bold\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.boldState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.boldState, $event, 'bold')\n            \"\n          />\n          <sky-checkbox\n            iconName=\"text-italic\"\n            label=\"Italicized\"\n            title=\"Italicized\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.italicState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.italicState, $event, 'italic')\n            \"\n          />\n          <sky-checkbox\n            iconName=\"text-underline\"\n            label=\"Underline\"\n            title=\"Underline\"\n            [disabled]=\"disabled\"\n            [ngModel]=\"styleState.underlineState\"\n            (ngModelChange)=\"\n              toggleFontStyle(styleState.underlineState, $event, 'underline')\n            \"\n          />\n        </div>\n      }\n      @case ('color') {\n        <div class=\"sky-text-editor-colorpicker-group\">\n          <div class=\"sky-text-editor-colorpicker-container\">\n            <sky-colorpicker\n              #colorPicker\n              class=\"sky-text-editor-font-color-picker\"\n              label=\"Font color\"\n              pickerButtonIcon=\"color-line\"\n              [messageStream]=\"colorpickerStream\"\n              [showResetButton]=\"false\"\n              (selectedColorChanged)=\"onColorpickerColorChanged($event)\"\n            >\n              <input\n                outputFormat=\"hex\"\n                type=\"text\"\n                [allowTransparency]=\"false\"\n                [disabled]=\"disabled\"\n                [ngModel]=\"styleState.fontColor\"\n                [skyColorpickerInput]=\"colorPicker\"\n              />\n            </sky-colorpicker>\n          </div>\n          <div class=\"sky-text-editor-colorpicker-container\">\n            <sky-colorpicker\n              #backColorPicker\n              class=\"sky-text-editor-background-color-picker\"\n              label=\"Background color\"\n              pickerButtonIcon=\"text-color\"\n              [messageStream]=\"backColorpickerStream\"\n              [showResetButton]=\"false\"\n              (selectedColorChanged)=\"onColorpickerColorChanged($event, true)\"\n            >\n              <input\n                outputFormat=\"rgba\"\n                type=\"text\"\n                [allowTransparency]=\"true\"\n                [disabled]=\"disabled\"\n                [ngModel]=\"styleState.backColor\"\n                [skyColorpickerInput]=\"backColorPicker\"\n              />\n            </sky-colorpicker>\n          </div>\n        </div>\n      }\n      @case ('list') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Bulleted list\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Bulleted list\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('insertUnorderedList')\"\n          >\n            <sky-icon iconName=\"text-bullet-list\" />\n          </button>\n          <button\n            aria-label=\"Numbered list\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Numbered list\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('insertOrderedList')\"\n          >\n            <sky-icon iconName=\"text-number-list-ltr\" />\n          </button>\n        </div>\n      }\n      @case ('alignment') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Align left\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align left\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyLeft')\"\n          >\n            <sky-icon iconName=\"text-align-left\" />\n          </button>\n          <button\n            aria-label=\"Align center\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align center\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyCenter')\"\n          >\n            <sky-icon iconName=\"text-align-center\" />\n          </button>\n          <button\n            aria-label=\"Align right\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Align right\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('justifyRight')\"\n          >\n            <sky-icon iconName=\"text-align-right\" />\n          </button>\n        </div>\n      }\n      @case ('indentation') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Outdent\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Outdent\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('outdent')\"\n          >\n            <sky-icon iconName=\"text-indent-decrease\" />\n          </button>\n          <button\n            aria-label=\"Indent\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Indent\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('indent')\"\n          >\n            <sky-icon iconName=\"text-indent-increase\" />\n          </button>\n        </div>\n      }\n      @case ('undo-redo') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Undo\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Undo\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('undo')\"\n          >\n            <sky-icon iconName=\"arrow-undo\" />\n          </button>\n          <button\n            aria-label=\"Redo\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Redo\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            (click)=\"execCommand('redo')\"\n          >\n            <sky-icon iconName=\"arrow-redo\" />\n          </button>\n        </div>\n      }\n      @case ('link') {\n        <div class=\"sky-switch-icon-group\">\n          <button\n            aria-label=\"Link\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Link\"\n            type=\"button\"\n            [disabled]=\"disabled\"\n            [ngClass]=\"{\n              'icon-btn-active': styleState.linkState\n            }\"\n            (click)=\"link()\"\n          >\n            <sky-icon iconName=\"link\" />\n          </button>\n          <button\n            aria-label=\"Unlink\"\n            class=\"sky-btn sky-btn-default sky-btn-icon\"\n            title=\"Unlink\"\n            type=\"button\"\n            [disabled]=\"!styleState.linkState || disabled\"\n            (click)=\"unlink()\"\n          >\n            <sky-icon iconName=\"link-dismiss\" />\n          </button>\n        </div>\n      }\n    }\n  </sky-toolbar-item>\n}\n", styles: [".sky-text-editor-toolbar-action:not(.sky-theme-modern *){--sky-override-text-editor-border-radius: 0;--sky-override-text-editor-button-border-outer-radius: 3px;--sky-override-text-editor-button-border: 1px solid #cdcfd2;--sky-override-text-editor-colorpicker-spacing: 10px;--sky-override-text-editor-colorpicker-top: 3px}.sky-text-editor-toolbar-action .sky-text-editor-font-picker ::ng-deep .sky-dropdown-button-content-container{width:140px;height:20px;text-align:left}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group{display:flex}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group .sky-text-editor-colorpicker-container{position:relative;top:var(--sky-override-text-editor-colorpicker-top, -2px);margin-right:var(--sky-override-text-editor-colorpicker-spacing, var(--sky-space-gap-action_group-m))}.sky-text-editor-toolbar-action .sky-text-editor-colorpicker-group .sky-text-editor-colorpicker-container:last-child{margin-right:0}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn{margin-left:0;margin-right:0;border-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-right:none}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn:first-of-type{border-top-left-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-bottom-left-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s))}.sky-text-editor-toolbar-action .sky-switch-icon-group .sky-btn:last-of-type{border-top-right-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-bottom-right-radius:var(--sky-override-text-editor-button-border-outer-radius, var(--sky-border-radius-s));border-right:var(--sky-override-text-editor-button-border, none)}\n"] }]
        }], propDecorators: { editorFocusStream: [{
                type: Input
            }], fontList: [{
                type: Input
            }], fontSizeList: [{
                type: Input
            }], toolbarActions: [{
                type: Input
            }], linkWindowOptions: [{
                type: Input
            }], styleState: [{
                type: Input
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * The text editor component lets users format and manipulate text.
 */
class SkyTextEditorComponent {
    /**
     * Whether to disable the text editor on template-driven forms. Don't use this input on reactive forms because they may overwrite the input or leave the control out of sync.
     * To set the disabled state on reactive forms, use the `FormControl` instead.
     * @default false
     */
    set disabled(value) {
        if (value !== this.disabled) {
            this.#_disabled = value;
            this.#applyDisabledState();
        }
    }
    get disabled() {
        return this.#_disabled;
    }
    /**
     * The fonts to include in the font picker.
     * @default [{name: 'Blackbaud Sans', value: '"Blackbaud Sans", Arial, sans-serif'}, {name: 'Arial', value: 'Arial'}, {name: 'Arial Black', value: '"Arial Black"'}, {name: 'Courier New', value: '"Courier New"'}, {name: 'Georgia', value: 'Georgia, serif'}, {name: 'Tahoma', value: 'Tahoma, Geneva, sans-serif'}, {name: 'Times New Roman', value: '"Times New Roman"'}, {name: 'Trebuchet MS', value: '"Trebuchet MS", sans-serif'}, {name: 'Verdana', value: 'Verdana, Geneva, sans-serif'}]
     */
    set fontList(value) {
        this.#_fontList = value || FONT_LIST_DEFAULTS;
    }
    get fontList() {
        return this.#_fontList;
    }
    /**
     * The font sizes to include in the font size picker.
     * @default [6, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 20, 22, 24, 26, 28, 36, 48]
     */
    set fontSizeList(value) {
        this.#_fontSizeList = value || FONT_SIZE_LIST_DEFAULTS;
    }
    get fontSizeList() {
        return this.#_fontSizeList;
    }
    /**
     * The unique ID attribute for the text editor.
     * By default, the component generates a random ID.
     */
    set id(value) {
        this.#id = value || this.#defaultId;
    }
    get id() {
        return this.#id;
    }
    /**
     * The initial styles for all content, including background color, font size, and link state.
     */
    set initialStyleState(state) {
        // Do not update the state after initialization has taken place
        /* istanbul ignore else */
        if (!this.#initialized) {
            this.#_initialStyleState = {
                ...STYLE_STATE_DEFAULTS,
                ...state,
            };
        }
    }
    get initialStyleState() {
        return this.#_initialStyleState;
    }
    /**
     * The text to display as the text editor's label.
     */
    set labelText(value) {
        this.#_labelText = value;
        this.#updateA11yAttributes();
    }
    get labelText() {
        return this.#_labelText;
    }
    /**
     * The menus to include in the menu bar.
     * @default [ 'edit', 'format' ]
     */
    set menus(value) {
        this.#_menus = value || MENU_DEFAULTS;
    }
    get menus() {
        return this.#_menus;
    }
    /**
     * The merge fields to include in the merge field menu.
     */
    set mergeFields(value) {
        this.#_mergeFields = value || [];
    }
    get mergeFields() {
        return this.#_mergeFields;
    }
    /**
     * Placeholder text to display when the text entry area is empty.
     */
    set placeholder(value) {
        /* istanbul ignore else */
        if (value !== this.#_placeholder) {
            this.#_placeholder = value || '';
            if (this.#initialized) {
                this.#adapterService.setPlaceholder(value);
            }
        }
    }
    get placeholder() {
        return this.#_placeholder;
    }
    /**
     * The actions to include in the toolbar in the specified order.
     * @default [ 'font-family', 'font-size', 'font-style', 'color', 'list', 'link ]
     */
    set toolbarActions(value) {
        this.#_toolbarActions = value || TOOLBAR_ACTION_DEFAULTS;
    }
    get toolbarActions() {
        return this.#_toolbarActions;
    }
    /**
     * The target window options for adding a hyperlink.
     * @default [ 'new', 'existing' ]
     */
    set linkWindowOptions(value) {
        this.#_linkWindowOptions = value ?? LINK_WINDOW_OPTIONS_DEFAULTS;
    }
    get linkWindowOptions() {
        return this.#_linkWindowOptions;
    }
    /**
     * The internal value of the control.
     */
    set value(value) {
        // Normalize value and set any empty state to an empty string.
        let normalizedValue;
        const valueTrimmed = value?.trim();
        if (!value ||
            valueTrimmed === '<p></p>' ||
            valueTrimmed === '<br>' ||
            valueTrimmed === '<p><br></p>') {
            normalizedValue = '';
        }
        else {
            normalizedValue = value;
        }
        normalizedValue = this.#sanitizationService
            .sanitize(normalizedValue)
            .trim();
        if (this.#_value !== normalizedValue) {
            this.#_value = normalizedValue;
            // Update angular form control if model has been normalized.
            /* istanbul ignore else */
            if (this.ngControl?.control &&
                normalizedValue !== this.ngControl.control.value) {
                this.ngControl.control.setValue(normalizedValue, {
                    emitModelToViewChange: false,
                });
            }
            // #initIframe() will do another check later to see if the editor should
            // receive focus if not initialized before this is called.
            this.#checkAutofocusAndFocus();
        }
    }
    get value() {
        return this.#_value;
    }
    #defaultId;
    #id;
    #focusInitialized;
    #initialized;
    #ngUnsubscribe;
    #_fontList;
    #_fontSizeList;
    #_labelText;
    #_mergeFields;
    #_menus;
    #_toolbarActions;
    #_linkWindowOptions;
    #_disabled;
    #_initialStyleState;
    #_placeholder;
    #_value;
    #adapterService;
    #changeDetector;
    #coreAdapterService;
    #editorService;
    #idSvc;
    #sanitizationService;
    #zone;
    constructor() {
        /**
         * Whether to put focus on the editor after it renders.
         */
        this.autofocus = false;
        /**
         * Whether the text editor is stacked on another form component. When specified,
         * the appropriate vertical spacing is automatically added to the text editor.
         */
        this.stacked = false;
        this.editorFocusStream = new Subject();
        this.formControlClass = !!inject(SkyInputBoxHostService, {
            optional: true,
        });
        this.editorFocused = false;
        this.#focusInitialized = false;
        this.#initialized = false;
        this.#ngUnsubscribe = new Subject();
        this.#_fontList = FONT_LIST_DEFAULTS;
        this.#_fontSizeList = FONT_SIZE_LIST_DEFAULTS;
        this.#_mergeFields = [];
        this.#_menus = MENU_DEFAULTS;
        this.#_toolbarActions = TOOLBAR_ACTION_DEFAULTS;
        this.#_linkWindowOptions = LINK_WINDOW_OPTIONS_DEFAULTS;
        this.#_disabled = false;
        this.#_initialStyleState = Object.assign({}, STYLE_STATE_DEFAULTS);
        this.#_placeholder = '';
        this.#_value = '<p></p>';
        this.#adapterService = inject(SkyTextEditorAdapterService);
        this.#changeDetector = inject(ChangeDetectorRef);
        this.#coreAdapterService = inject(SkyCoreAdapterService);
        this.#editorService = inject(SkyTextEditorService);
        this.#idSvc = inject(SkyIdService);
        this.#sanitizationService = inject(SkyTextSanitizationService);
        this.#zone = inject(NgZone);
        this.errorId = this.#idSvc.generateId();
        this.ngControl = inject(NgControl);
        this.requiredState = inject(SkyRequiredStateDirective);
        /* istanbul ignore next */
        this.#_onTouched = () => { };
        /* istanbul ignore next */
        this.#_onChange = () => { };
        this.#id = this.#defaultId = this.#idSvc.generateId();
        this.ngControl.valueAccessor = this;
    }
    ngAfterViewInit() {
        this.#initIframe();
    }
    ngOnDestroy() {
        this.#adapterService.removeObservers(this.#editorService.editor);
        this.#ngUnsubscribe.next();
        this.#ngUnsubscribe.complete();
    }
    onIframeLoad() {
        // Reinitialize the editor if it already exists to cover situations where the text editor might have been moved in the DOM.
        if (this.#editorService.isInitialized) {
            this.#initIframe();
        }
    }
    /**
     * Implemented as part of ControlValueAccessor.
     */
    writeValue(value) {
        this.value = value;
        // Update HTML if necessary.
        if (this.#initialized) {
            const editorValue = this.#adapterService.getEditorInnerHtml();
            if (editorValue !== this.#_value) {
                this.#adapterService.setEditorInnerHtml(this.#_value);
            }
        }
    }
    /**
     * Implemented as part of ControlValueAccessor.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this.#_onChange = fn;
    }
    /**
     * Implemented as part of ControlValueAccessor.
     */
    registerOnTouched(fn) {
        this.#_onTouched = fn;
    }
    /**
     * Implemented as part of ControlValueAccessor.
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    #checkAutofocusAndFocus() {
        // Don't set focus on the editor if the iframe isn't initialized.
        // Autofocus isn't testable in Firefox and IE.
        /* istanbul ignore next */
        if (this.autofocus && this.#initialized && !this.#focusInitialized) {
            this.#adapterService.focusEditor();
            this.#focusInitialized = true;
        }
    }
    #updateStyle() {
        this.#_initialStyleState = {
            ...this.#_initialStyleState,
            ...this.#adapterService.getStyleState(),
        };
    }
    #initIframe() {
        this.#adapterService.initEditor(this.id, this.iframeRef.nativeElement, this.initialStyleState, this.placeholder);
        this.ngControl.statusChanges
            ?.pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.#updateA11yAttributes();
            // Trigger change detection when the field status is modified programmatically.
            this.#changeDetector.markForCheck();
        });
        this.#editorService
            .inputListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            // Angular doesn't run change detection for changes originating inside an iframe,
            // so we have to call the onChange() event inside NgZone to force change propagation to consuming components.
            this.#zone.run(() => {
                this.#viewToModelUpdate();
            });
        });
        this.#editorService
            .selectionChangeListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.#updateStyle();
            this.editorFocusStream.next();
        });
        this.#editorService
            .clickListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.editorFocusStream.next();
        });
        this.#editorService
            .blurListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            // Angular doesn't run change detection for changes originating inside an iframe,
            // so we have to run markForCheck() inside the NgZone to force change propagation to consuming components.
            this.#zone.run(() => {
                this.#_onTouched();
                this.editorFocused = false;
                this.#changeDetector.markForCheck();
            });
        });
        this.#editorService
            .commandChangeListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            this.#updateStyle();
            this.#viewToModelUpdate();
        });
        this.#editorService
            .focusListener()
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe(() => {
            // Angular doesn't run change detection for changes originating inside an iframe,
            // so we have to run markForCheck() inside the NgZone to force change propagation to consuming components.
            this.#zone.run(() => {
                this.editorFocused = true;
                this.#changeDetector.markForCheck();
            });
        });
        this.#adapterService.setEditorInnerHtml(this.#_value);
        this.#updateA11yAttributes();
        /* istanbul ignore next */
        if (this.autofocus) {
            this.#adapterService.focusEditor();
        }
        this.#applyDisabledState();
        this.#initialized = true;
        this.#focusInitialized = false;
        this.#checkAutofocusAndFocus();
    }
    #updateA11yAttributes() {
        if (this.#editorService.isInitialized) {
            this.#adapterService.setLabelAttribute(this.labelText);
            this.#adapterService.setErrorAttributes(this.labelText ? this.errorId : '', this.ngControl.errors);
            this.#adapterService.setRequiredAttribute(this.requiredState.isRequired());
        }
    }
    #viewToModelUpdate(emitChange = true) {
        this.value = this.#adapterService.getEditorInnerHtml();
        /* istanbul ignore else */
        if (emitChange) {
            this.#_onChange(this.#_value);
        }
    }
    #applyDisabledState() {
        // Update focusableChildren inside the iframe.
        let focusableChildren;
        /* istanbul ignore else */
        if (this.iframeRef?.nativeElement.contentDocument?.body) {
            focusableChildren = this.#coreAdapterService.getFocusableChildren(this.iframeRef.nativeElement.contentDocument.body, {
                ignoreVisibility: true,
                ignoreTabIndex: true,
            });
            if (this.#_disabled) {
                this.#adapterService.disableEditor(focusableChildren, this.iframeRef.nativeElement);
            }
            else {
                this.#adapterService.enableEditor(focusableChildren, this.iframeRef.nativeElement);
            }
            this.#changeDetector.markForCheck();
        }
    }
    /* istanbul ignore next */
    #_onTouched;
    /* istanbul ignore next */
    #_onChange;
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkyTextEditorComponent, isStandalone: true, selector: "sky-text-editor", inputs: { autofocus: "autofocus", disabled: ["disabled", "disabled", booleanAttribute], fontList: "fontList", fontSizeList: "fontSizeList", helpPopoverContent: "helpPopoverContent", helpPopoverTitle: "helpPopoverTitle", hintText: "hintText", id: "id", initialStyleState: "initialStyleState", labelText: "labelText", menus: "menus", mergeFields: "mergeFields", placeholder: "placeholder", stacked: ["stacked", "stacked", booleanAttribute], toolbarActions: "toolbarActions", linkWindowOptions: "linkWindowOptions", helpKey: "helpKey" }, host: { properties: { "class.sky-form-field-stacked": "this.stacked", "class.sky-form-control": "this.formControlClass" } }, providers: [
            SkyTextEditorService,
            SkyTextEditorSelectionService,
            SkyTextEditorAdapterService,
            { provide: SKY_FORM_ERRORS_ENABLED, useValue: true },
        ], viewQueries: [{ propertyName: "iframeRef", first: true, predicate: ["iframe"], descendants: true }, { propertyName: "inputTemplateRef", first: true, predicate: ["inputTemplateRef"], descendants: true, read: TemplateRef, static: true }], hostDirectives: [{ directive: i1$3.SkyRequiredStateDirective, inputs: ["required", "required"] }], ngImport: i0, template: "<div\n  class=\"sky-text-editor\"\n  [ngClass]=\"{\n    'sky-text-editor-disabled': disabled,\n    'sky-text-editor-wrapper-focused': editorFocused,\n    'sky-text-editor-invalid':\n      ngControl.errors && (ngControl.touched || ngControl.dirty)\n  }\"\n>\n  <div class=\"sky-text-editor-label-wrapper\">\n    @if (labelText) {\n      <label\n        class=\"sky-control-label\"\n        [ngClass]=\"{\n          'sky-control-label-required': requiredState.isRequired()\n        }\"\n        >{{ labelText }}</label\n      >\n      @if (helpPopoverContent || helpKey) {\n        <span class=\"sky-control-help-container\">\n          <sky-help-inline\n            [helpKey]=\"helpKey\"\n            [labelText]=\"labelText\"\n            [popoverContent]=\"helpPopoverContent\"\n            [popoverTitle]=\"helpPopoverTitle\"\n          />\n        </span>\n      }\n    }\n  </div>\n  @if (\n    (menus && menus.length) > 0 || (toolbarActions && toolbarActions.length > 0)\n  ) {\n    <sky-toolbar class=\"sky-text-editor-toolbar\">\n      @if (menus && menus.length > 0) {\n        <sky-toolbar-section\n          aria-label=\"Text formatting\"\n          class=\"menubar\"\n          role=\"toolbar\"\n        >\n          <sky-text-editor-menubar\n            [disabled]=\"disabled\"\n            [editorFocusStream]=\"editorFocusStream\"\n            [menus]=\"menus\"\n            [mergeFields]=\"mergeFields\"\n          />\n        </sky-toolbar-section>\n      }\n      @if (toolbarActions && toolbarActions.length > 0) {\n        <sky-toolbar-section\n          aria-label=\"Text formatting\"\n          class=\"toolbar\"\n          role=\"toolbar\"\n        >\n          <sky-text-editor-toolbar\n            [disabled]=\"disabled\"\n            [editorFocusStream]=\"editorFocusStream\"\n            [fontList]=\"fontList\"\n            [fontSizeList]=\"fontSizeList\"\n            [linkWindowOptions]=\"linkWindowOptions\"\n            [toolbarActions]=\"toolbarActions\"\n            [styleState]=\"initialStyleState\"\n          />\n        </sky-toolbar-section>\n      }\n    </sky-toolbar>\n  }\n  <iframe\n    #iframe\n    class=\"sky-text-editor-wrapper\"\n    src=\"about:blank\"\n    allow=\"clipboard-read *; clipboard-write *\"\n    [attr.title]=\"\n      labelText || ('skyux_text_editor_iframe_title_default' | skyLibResources)\n    \"\n    [attr.aria-describedby]=\"hintText ? hintTextEl.id : undefined\"\n    [ngClass]=\"{\n      'sky-text-editor-wrapper-disabled': disabled\n    }\"\n    (load)=\"onIframeLoad()\"\n  >\n  </iframe>\n</div>\n<div\n  #hintTextEl=\"skyId\"\n  skyId\n  class=\"sky-text-editor-hint-text\"\n  [skyThemeClass]=\"{\n    'sky-font-deemphasized': 'default',\n    'sky-font-hint-text-s': 'modern'\n  }\"\n>\n  {{ hintText }}\n</div>\n<sky-form-errors\n  class=\"sky-text-editor-errors\"\n  [id]=\"errorId\"\n  [errors]=\"ngControl.errors\"\n  [labelText]=\"labelText\"\n  [touched]=\"ngControl.touched\"\n  [dirty]=\"ngControl.dirty\"\n>\n  <ng-content select=\"sky-form-error\" />\n</sky-form-errors>\n", styles: [".sky-text-editor:not(.sky-theme-modern *){--sky-override-text-editor-background-color: white;--sky-override-text-editor-toolbar-background-color: white;--sky-override-text-editor-label-background-color: transparent;--sky-override-text-editor-border-error: 1px solid var(--sky-highlight-color-danger);--sky-override-text-editor-border-focused: 1px solid var(--sky-highlight-color-info);--sky-override-text-editor-border-radius: 0;--sky-override-text-editor-border: 1px solid #cdcfd2;--sky-override-text-editor-box-shadow-error: 0 0 8px rgba(239, 64, 68, .6);--sky-override-text-editor-box-shadow-focused: 0 0 8px rgba(0, 180, 241, .6);--sky-override-text-editor-box-shadow: none;--sky-override-text-editor-disabled-cursor: default;--sky-override-text-editor-label-color: var(--sky-text-color-default);--sky-override-text-editor-label-color-focused: var(--sky-text-color-default);--sky-override-text-editor-label-color-invalid: var(--sky-text-color-default);--sky-override-text-editor-label-display: flex;--sky-override-text-editor-label-font-size: 15px;--sky-override-text-editor-label-font-weight: 400;--sky-override-text-editor-label-line-height: normal;--sky-override-text-editor-label-margin-bottom: 5px;--sky-override-text-editor-label-padding: 0;--sky-override-text-editor-toolbar-border: 1px solid #cdcfd2;--sky-override-text-editor-toolbar-item-spacing: 0 20px 10px 0;--sky-override-text-editor-toolbar-section-padding: 10px 10px 0 10px;--sky-override-text-editor-top-toolbar-bottom-padding: 0;--sky-override-text-editor-wrapper-background-color-disabled: var( --sky-background-color-disabled );--sky-override-text-editor-wrapper-padding: 1rem}.sky-text-editor-hint-text:not(.sky-theme-modern *){--sky-override-text-editor-hint-text-space: 5px}.sky-theme-modern:not(.sky-theme-brand-base) .sky-text-editor{--sky-override-text-editor-background-color: var(--modern-color-white);--sky-override-text-editor-border-color: #d2d2d2;--sky-override-text-editor-box-shadow-focused: inset 0 0 0 var(--sky-border-width-input-focus) var(--sky-color-border-input-focus), var(--sky-elevation-focus);--sky-override-text-editor-focus-shadow: 0px 1px 3px 0px rgba(0, 0, 0, .3);--sky-override-text-editor-label-color: var(--sky-text-color-deemphasized);--sky-override-text-editor-label-padding: 10px 10px 0 10px;--sky-override-text-editor-toolbar-section-padding: 10px;--sky-override-text-editor-top-toolbar-bottom-padding: 0}sky-text-editor.sky-form-field-stacked{display:block}.sky-text-editor{border-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-base) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-base)))}.sky-text-editor.sky-text-editor-disabled{background-color:var(--sky-color-background-input-disabled);box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-disabled) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-disabled)));cursor:var(--sky-override-text-editor-disabled-cursor, not-allowed)}.sky-text-editor .sky-text-editor-label-wrapper:not(:empty){background-color:var(--sky-override-text-editor-label-background-color, var(--sky-color-background-input-base));display:var(--sky-override-text-editor-label-display, inline-block);padding:var(--sky-override-text-editor-label-padding, var(--sky-comp-input-label-space-inset-top) var(--sky-comp-input-value-space-inset-right) 0 var(--sky-comp-input-value-space-inset-left));width:100%;color:var(--sky-override-text-editor-label-color, var(--sky-color-text-default))}.sky-text-editor .sky-text-editor-label-wrapper:not(:empty) label{font-size:var(--sky-override-text-editor-label-font-size, var(--sky-font-size-input-label));font-style:var(--sky-font-style-input-label);font-weight:var(--sky-override-text-editor-label-font-weight, var(--sky-font-weight-input-label));letter-spacing:var(--sky-font-letter_spacing-input-label);line-height:var(--sky-override-text-editor-label-line-height, var(--sky-font-line_height-input-label));margin-bottom:var(--sky-override-text-editor-label-margin-bottom, 0)}.sky-text-editor .sky-text-editor-wrapper{display:flex;flex-wrap:wrap;background-color:var(--sky-override-text-editor-background-color, var(--sky-color-background-input-base));width:100%;height:300px;padding:var(--sky-override-text-editor-wrapper-padding, var(--sky-comp-text_editor-space-inset-top) var(--sky-comp-text_editor-space-inset-right) var(--sky-comp-text_editor-space-inset-bottom) var(--sky-comp-text_editor-space-inset-left));font-size:1.2rem;border-bottom-left-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-bottom-right-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-top:none;border-right:var(--sky-override-text-editor-border, none);border-bottom:var(--sky-override-text-editor-border, none);border-left:var(--sky-override-text-editor-border, none);box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-base) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-base)));overflow-y:auto;outline:none}.sky-text-editor .sky-text-editor-wrapper.sky-text-editor-wrapper-disabled{background-color:var(--sky-override-text-editor-wrapper-background-color-disabled, var(--sky-color-background-input-disabled));box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-disabled) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-disabled)))}.sky-text-editor.sky-text-editor-invalid .sky-text-editor-wrapper{box-shadow:var(--sky-override-text-editor-box-shadow-error, inset 0 0 0 var(--sky-border-width-input-error) var(--sky-color-border-input-error));border:var(--sky-override-text-editor-border-error, none);outline:none}.sky-text-editor.sky-text-editor-invalid .sky-text-editor-label-wrapper{color:var(--sky-override-text-editor-label-color-invalid, var(--sky-color-text-danger))}.sky-text-editor.sky-text-editor-wrapper-focused .sky-text-editor-wrapper{box-shadow:var(--sky-override-text-editor-box-shadow-focused, inset 0 0 0 var(--sky-border-width-input-focus) var(--sky-color-border-input-focus));border:var(--sky-override-text-editor-border-focused, none);outline:none}.sky-text-editor.sky-text-editor-wrapper-focused .sky-text-editor-label-wrapper{color:var(--sky-override-text-editor-label-color-focused, var(--sky-color-text-action))}.sky-text-editor:not(.sky-text-editor-wrapper-focused) .sky-text-editor-wrapper:hover:not(:active){box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-hover) var(--sky-color-border-input-hover))}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-container{background-color:var(--sky-override-text-editor-toolbar-background-color, var(--sky-color-background-input-base))!important}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-section{padding:var(--sky-override-text-editor-toolbar-section-padding, var(--sky-comp-toolbar-space-inset-top) var(--sky-comp-input-value-space-inset-right) var(--sky-comp-toolbar-space-inset-bottom) var(--sky-comp-input-value-space-inset-left))!important;border-top:var(--sky-override-text-editor-toolbar-border, none)!important}.sky-text-editor .sky-text-editor-toolbar sky-toolbar-section:not(:last-of-type) .sky-toolbar-section{padding-bottom:var(--sky-override-text-editor-top-toolbar-bottom-padding, var(--sky-comp-toolbar-space-inset-bottom))!important;border-top:none!important}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-sectioned{border-left:var(--sky-override-text-editor-toolbar-border, none);border-right:var(--sky-override-text-editor-toolbar-border, none)}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-item{margin:var(--sky-override-text-editor-toolbar-item-spacing, 0 var(--sky-space-gap-action_group-xl) 0 0)!important}.sky-text-editor .sky-text-editor-toolbar .sky-dropdown-button{border:none}.sky-text-editor .sky-text-editor-toolbar sky-text-editor-menubar,.sky-text-editor .sky-text-editor-toolbar sky-text-editor-toolbar{display:flex;flex-wrap:wrap}.sky-text-editor-hint-text{margin-top:var(--sky-override-text-editor-hint-text-space, var(--sky-space-gap-stacked_supplemental-s))}.sky-theme-modern .sky-text-editor .sky-text-editor-label-wrapper:not(:empty){transition:border-color .15s,box-shadow .15s,color .15s}.sky-theme-modern .sky-text-editor .sky-text-editor-wrapper{transition:border-color .15s,box-shadow .15s,color .15s}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: SkyHelpInlineModule }, { kind: "component", type: i3$2.λ1, selector: "sky-help-inline", inputs: ["ariaControls", "ariaExpanded", "ariaLabel", "helpKey", "labelledBy", "labelText", "popoverContent", "popoverTitle"], outputs: ["actionClick"] }, { kind: "ngmodule", type: SkyIdModule }, { kind: "directive", type: i3.λ2, selector: "[skyId]", exportAs: ["skyId"] }, { kind: "component", type: SkyTextEditorMenubarComponent, selector: "sky-text-editor-menubar", inputs: ["editorFocusStream", "menus", "mergeFields", "disabled"] }, { kind: "component", type: SkyTextEditorToolbarComponent, selector: "sky-text-editor-toolbar", inputs: ["editorFocusStream", "fontList", "fontSizeList", "toolbarActions", "linkWindowOptions", "styleState", "disabled"] }, { kind: "ngmodule", type: SkyThemeModule }, { kind: "directive", type: i4.λ2, selector: "[skyThemeClass]", inputs: ["class", "skyThemeClass"] }, { kind: "ngmodule", type: SkyToolbarModule }, { kind: "component", type: i6.λ37, selector: "sky-toolbar", inputs: ["listDescriptor"] }, { kind: "component", type: i6.λ38, selector: "sky-toolbar-section" }, { kind: "ngmodule", type: SkyFormErrorsModule }, { kind: "component", type: i1$3.λ21, selector: "sky-form-errors", inputs: ["errors", "labelText", "touched", "dirty"] }, { kind: "ngmodule", type: SkyTextEditorResourcesModule }, { kind: "pipe", type: i3$1.SkyLibResourcesPipe, name: "skyLibResources" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sky-text-editor', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        SkyTextEditorService,
                        SkyTextEditorSelectionService,
                        SkyTextEditorAdapterService,
                        { provide: SKY_FORM_ERRORS_ENABLED, useValue: true },
                    ], hostDirectives: [
                        {
                            directive: SkyRequiredStateDirective,
                            inputs: ['required'],
                        },
                    ], imports: [
                        CommonModule,
                        SkyHelpInlineModule,
                        SkyIdModule,
                        SkyTextEditorMenubarComponent,
                        SkyTextEditorToolbarComponent,
                        SkyThemeModule,
                        SkyToolbarModule,
                        SkyFormErrorsModule,
                        SkyTextEditorResourcesModule,
                    ], template: "<div\n  class=\"sky-text-editor\"\n  [ngClass]=\"{\n    'sky-text-editor-disabled': disabled,\n    'sky-text-editor-wrapper-focused': editorFocused,\n    'sky-text-editor-invalid':\n      ngControl.errors && (ngControl.touched || ngControl.dirty)\n  }\"\n>\n  <div class=\"sky-text-editor-label-wrapper\">\n    @if (labelText) {\n      <label\n        class=\"sky-control-label\"\n        [ngClass]=\"{\n          'sky-control-label-required': requiredState.isRequired()\n        }\"\n        >{{ labelText }}</label\n      >\n      @if (helpPopoverContent || helpKey) {\n        <span class=\"sky-control-help-container\">\n          <sky-help-inline\n            [helpKey]=\"helpKey\"\n            [labelText]=\"labelText\"\n            [popoverContent]=\"helpPopoverContent\"\n            [popoverTitle]=\"helpPopoverTitle\"\n          />\n        </span>\n      }\n    }\n  </div>\n  @if (\n    (menus && menus.length) > 0 || (toolbarActions && toolbarActions.length > 0)\n  ) {\n    <sky-toolbar class=\"sky-text-editor-toolbar\">\n      @if (menus && menus.length > 0) {\n        <sky-toolbar-section\n          aria-label=\"Text formatting\"\n          class=\"menubar\"\n          role=\"toolbar\"\n        >\n          <sky-text-editor-menubar\n            [disabled]=\"disabled\"\n            [editorFocusStream]=\"editorFocusStream\"\n            [menus]=\"menus\"\n            [mergeFields]=\"mergeFields\"\n          />\n        </sky-toolbar-section>\n      }\n      @if (toolbarActions && toolbarActions.length > 0) {\n        <sky-toolbar-section\n          aria-label=\"Text formatting\"\n          class=\"toolbar\"\n          role=\"toolbar\"\n        >\n          <sky-text-editor-toolbar\n            [disabled]=\"disabled\"\n            [editorFocusStream]=\"editorFocusStream\"\n            [fontList]=\"fontList\"\n            [fontSizeList]=\"fontSizeList\"\n            [linkWindowOptions]=\"linkWindowOptions\"\n            [toolbarActions]=\"toolbarActions\"\n            [styleState]=\"initialStyleState\"\n          />\n        </sky-toolbar-section>\n      }\n    </sky-toolbar>\n  }\n  <iframe\n    #iframe\n    class=\"sky-text-editor-wrapper\"\n    src=\"about:blank\"\n    allow=\"clipboard-read *; clipboard-write *\"\n    [attr.title]=\"\n      labelText || ('skyux_text_editor_iframe_title_default' | skyLibResources)\n    \"\n    [attr.aria-describedby]=\"hintText ? hintTextEl.id : undefined\"\n    [ngClass]=\"{\n      'sky-text-editor-wrapper-disabled': disabled\n    }\"\n    (load)=\"onIframeLoad()\"\n  >\n  </iframe>\n</div>\n<div\n  #hintTextEl=\"skyId\"\n  skyId\n  class=\"sky-text-editor-hint-text\"\n  [skyThemeClass]=\"{\n    'sky-font-deemphasized': 'default',\n    'sky-font-hint-text-s': 'modern'\n  }\"\n>\n  {{ hintText }}\n</div>\n<sky-form-errors\n  class=\"sky-text-editor-errors\"\n  [id]=\"errorId\"\n  [errors]=\"ngControl.errors\"\n  [labelText]=\"labelText\"\n  [touched]=\"ngControl.touched\"\n  [dirty]=\"ngControl.dirty\"\n>\n  <ng-content select=\"sky-form-error\" />\n</sky-form-errors>\n", styles: [".sky-text-editor:not(.sky-theme-modern *){--sky-override-text-editor-background-color: white;--sky-override-text-editor-toolbar-background-color: white;--sky-override-text-editor-label-background-color: transparent;--sky-override-text-editor-border-error: 1px solid var(--sky-highlight-color-danger);--sky-override-text-editor-border-focused: 1px solid var(--sky-highlight-color-info);--sky-override-text-editor-border-radius: 0;--sky-override-text-editor-border: 1px solid #cdcfd2;--sky-override-text-editor-box-shadow-error: 0 0 8px rgba(239, 64, 68, .6);--sky-override-text-editor-box-shadow-focused: 0 0 8px rgba(0, 180, 241, .6);--sky-override-text-editor-box-shadow: none;--sky-override-text-editor-disabled-cursor: default;--sky-override-text-editor-label-color: var(--sky-text-color-default);--sky-override-text-editor-label-color-focused: var(--sky-text-color-default);--sky-override-text-editor-label-color-invalid: var(--sky-text-color-default);--sky-override-text-editor-label-display: flex;--sky-override-text-editor-label-font-size: 15px;--sky-override-text-editor-label-font-weight: 400;--sky-override-text-editor-label-line-height: normal;--sky-override-text-editor-label-margin-bottom: 5px;--sky-override-text-editor-label-padding: 0;--sky-override-text-editor-toolbar-border: 1px solid #cdcfd2;--sky-override-text-editor-toolbar-item-spacing: 0 20px 10px 0;--sky-override-text-editor-toolbar-section-padding: 10px 10px 0 10px;--sky-override-text-editor-top-toolbar-bottom-padding: 0;--sky-override-text-editor-wrapper-background-color-disabled: var( --sky-background-color-disabled );--sky-override-text-editor-wrapper-padding: 1rem}.sky-text-editor-hint-text:not(.sky-theme-modern *){--sky-override-text-editor-hint-text-space: 5px}.sky-theme-modern:not(.sky-theme-brand-base) .sky-text-editor{--sky-override-text-editor-background-color: var(--modern-color-white);--sky-override-text-editor-border-color: #d2d2d2;--sky-override-text-editor-box-shadow-focused: inset 0 0 0 var(--sky-border-width-input-focus) var(--sky-color-border-input-focus), var(--sky-elevation-focus);--sky-override-text-editor-focus-shadow: 0px 1px 3px 0px rgba(0, 0, 0, .3);--sky-override-text-editor-label-color: var(--sky-text-color-deemphasized);--sky-override-text-editor-label-padding: 10px 10px 0 10px;--sky-override-text-editor-toolbar-section-padding: 10px;--sky-override-text-editor-top-toolbar-bottom-padding: 0}sky-text-editor.sky-form-field-stacked{display:block}.sky-text-editor{border-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-base) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-base)))}.sky-text-editor.sky-text-editor-disabled{background-color:var(--sky-color-background-input-disabled);box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-disabled) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-disabled)));cursor:var(--sky-override-text-editor-disabled-cursor, not-allowed)}.sky-text-editor .sky-text-editor-label-wrapper:not(:empty){background-color:var(--sky-override-text-editor-label-background-color, var(--sky-color-background-input-base));display:var(--sky-override-text-editor-label-display, inline-block);padding:var(--sky-override-text-editor-label-padding, var(--sky-comp-input-label-space-inset-top) var(--sky-comp-input-value-space-inset-right) 0 var(--sky-comp-input-value-space-inset-left));width:100%;color:var(--sky-override-text-editor-label-color, var(--sky-color-text-default))}.sky-text-editor .sky-text-editor-label-wrapper:not(:empty) label{font-size:var(--sky-override-text-editor-label-font-size, var(--sky-font-size-input-label));font-style:var(--sky-font-style-input-label);font-weight:var(--sky-override-text-editor-label-font-weight, var(--sky-font-weight-input-label));letter-spacing:var(--sky-font-letter_spacing-input-label);line-height:var(--sky-override-text-editor-label-line-height, var(--sky-font-line_height-input-label));margin-bottom:var(--sky-override-text-editor-label-margin-bottom, 0)}.sky-text-editor .sky-text-editor-wrapper{display:flex;flex-wrap:wrap;background-color:var(--sky-override-text-editor-background-color, var(--sky-color-background-input-base));width:100%;height:300px;padding:var(--sky-override-text-editor-wrapper-padding, var(--sky-comp-text_editor-space-inset-top) var(--sky-comp-text_editor-space-inset-right) var(--sky-comp-text_editor-space-inset-bottom) var(--sky-comp-text_editor-space-inset-left));font-size:1.2rem;border-bottom-left-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-bottom-right-radius:var(--sky-override-text-editor-border-radius, var(--sky-border-radius-s));border-top:none;border-right:var(--sky-override-text-editor-border, none);border-bottom:var(--sky-override-text-editor-border, none);border-left:var(--sky-override-text-editor-border, none);box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-base) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-base)));overflow-y:auto;outline:none}.sky-text-editor .sky-text-editor-wrapper.sky-text-editor-wrapper-disabled{background-color:var(--sky-override-text-editor-wrapper-background-color-disabled, var(--sky-color-background-input-disabled));box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-disabled) var(--sky-override-text-editor-border-color, var(--sky-color-border-input-disabled)))}.sky-text-editor.sky-text-editor-invalid .sky-text-editor-wrapper{box-shadow:var(--sky-override-text-editor-box-shadow-error, inset 0 0 0 var(--sky-border-width-input-error) var(--sky-color-border-input-error));border:var(--sky-override-text-editor-border-error, none);outline:none}.sky-text-editor.sky-text-editor-invalid .sky-text-editor-label-wrapper{color:var(--sky-override-text-editor-label-color-invalid, var(--sky-color-text-danger))}.sky-text-editor.sky-text-editor-wrapper-focused .sky-text-editor-wrapper{box-shadow:var(--sky-override-text-editor-box-shadow-focused, inset 0 0 0 var(--sky-border-width-input-focus) var(--sky-color-border-input-focus));border:var(--sky-override-text-editor-border-focused, none);outline:none}.sky-text-editor.sky-text-editor-wrapper-focused .sky-text-editor-label-wrapper{color:var(--sky-override-text-editor-label-color-focused, var(--sky-color-text-action))}.sky-text-editor:not(.sky-text-editor-wrapper-focused) .sky-text-editor-wrapper:hover:not(:active){box-shadow:var(--sky-override-text-editor-box-shadow, inset 0 0 0 var(--sky-border-width-input-hover) var(--sky-color-border-input-hover))}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-container{background-color:var(--sky-override-text-editor-toolbar-background-color, var(--sky-color-background-input-base))!important}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-section{padding:var(--sky-override-text-editor-toolbar-section-padding, var(--sky-comp-toolbar-space-inset-top) var(--sky-comp-input-value-space-inset-right) var(--sky-comp-toolbar-space-inset-bottom) var(--sky-comp-input-value-space-inset-left))!important;border-top:var(--sky-override-text-editor-toolbar-border, none)!important}.sky-text-editor .sky-text-editor-toolbar sky-toolbar-section:not(:last-of-type) .sky-toolbar-section{padding-bottom:var(--sky-override-text-editor-top-toolbar-bottom-padding, var(--sky-comp-toolbar-space-inset-bottom))!important;border-top:none!important}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-sectioned{border-left:var(--sky-override-text-editor-toolbar-border, none);border-right:var(--sky-override-text-editor-toolbar-border, none)}.sky-text-editor .sky-text-editor-toolbar .sky-toolbar-item{margin:var(--sky-override-text-editor-toolbar-item-spacing, 0 var(--sky-space-gap-action_group-xl) 0 0)!important}.sky-text-editor .sky-text-editor-toolbar .sky-dropdown-button{border:none}.sky-text-editor .sky-text-editor-toolbar sky-text-editor-menubar,.sky-text-editor .sky-text-editor-toolbar sky-text-editor-toolbar{display:flex;flex-wrap:wrap}.sky-text-editor-hint-text{margin-top:var(--sky-override-text-editor-hint-text-space, var(--sky-space-gap-stacked_supplemental-s))}.sky-theme-modern .sky-text-editor .sky-text-editor-label-wrapper:not(:empty){transition:border-color .15s,box-shadow .15s,color .15s}.sky-theme-modern .sky-text-editor .sky-text-editor-wrapper{transition:border-color .15s,box-shadow .15s,color .15s}\n"] }]
        }], ctorParameters: () => [], propDecorators: { autofocus: [{
                type: Input
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], fontList: [{
                type: Input
            }], fontSizeList: [{
                type: Input
            }], helpPopoverContent: [{
                type: Input
            }], helpPopoverTitle: [{
                type: Input
            }], hintText: [{
                type: Input
            }], id: [{
                type: Input
            }], initialStyleState: [{
                type: Input
            }], labelText: [{
                type: Input
            }], menus: [{
                type: Input
            }], mergeFields: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], stacked: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }, {
                type: HostBinding,
                args: ['class.sky-form-field-stacked']
            }], toolbarActions: [{
                type: Input
            }], linkWindowOptions: [{
                type: Input
            }], helpKey: [{
                type: Input
            }], iframeRef: [{
                type: ViewChild,
                args: ['iframe']
            }], inputTemplateRef: [{
                type: ViewChild,
                args: ['inputTemplateRef', {
                        read: TemplateRef,
                        static: true,
                    }]
            }], formControlClass: [{
                type: HostBinding,
                args: ['class.sky-form-control']
            }] } });

class SkyTextEditorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorModule, imports: [SkyTextEditorComponent], exports: [SkyTextEditorComponent, SkyFormErrorModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorModule, imports: [SkyTextEditorComponent, SkyFormErrorModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkyTextEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [SkyTextEditorComponent],
                    exports: [SkyTextEditorComponent, SkyFormErrorModule],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SkyRichTextDisplayModule, SkyTextEditorModule, SkyRichTextDisplayComponent as λ1, SkyTextEditorMenubarComponent as λ2, SkyTextEditorUrlModalComponent as λ3, SkyTextEditorToolbarComponent as λ4, SkyTextEditorComponent as λ5 };
//# sourceMappingURL=skyux-text-editor.mjs.map
