import { ValidationErrors } from '@angular/forms';
import { SkyAppWindowRef } from '@skyux/core';
import { EditorCommand } from '../types/editor-command';
import { EditorSetting } from '../types/editor-setting';
import { SkyTextEditorStyleState } from '../types/style-state';
import { UrlModalResult } from '../url-modal/text-editor-url-modal-result';
import { SkyTextEditorSelectionService } from './text-editor-selection.service';
import { SkyTextEditorService } from './text-editor.service';
import * as i0 from "@angular/core";
/**
 * @internal
 */
export declare class SkyTextEditorAdapterService {
    #private;
    constructor(selectionService: SkyTextEditorSelectionService, textEditorService: SkyTextEditorService, windowService: SkyAppWindowRef);
    /**
     * Creates a text editor inside the supplied iframe element.
     */
    initEditor(id: string, iframeElement: HTMLIFrameElement, styleState: SkyTextEditorStyleState, placeholder?: string): void;
    disableEditor(focusableChildren: HTMLElement[], textEditorNativeElement: HTMLElement): void;
    enableEditor(focusableChildren: HTMLElement[], textEditorNativeElement: HTMLElement): void;
    /**
     * Executes a command on the text editor with the corresponding id.
     */
    execCommand(editorCommand: EditorCommand): Promise<void>;
    getCurrentSelection(): Selection | null;
    /**
     * Returns a data URI using the provided text string.
     * Used to display a merge field inside a string of text.
     */
    getMergeFieldDataURI(text: string): string;
    getStyleState(): Partial<SkyTextEditorStyleState>;
    getEditorInnerHtml(): string;
    setEditorInnerHtml(value: string): void;
    focusEditor(): void;
    getLink(): UrlModalResult | undefined;
    getSelectedAnchorTag(): HTMLAnchorElement | null | undefined;
    saveSelection(): Range | undefined;
    selectElement(element: HTMLElement): void;
    setErrorAttributes(errorId: string, errors: ValidationErrors | null): void;
    setLabelAttribute(label: string | undefined): void;
    setPlaceholder(placeholder?: string): void;
    setRequiredAttribute(required: boolean): void;
    setFontSize(fontSize: number): Promise<void>;
    removeObservers(setting: EditorSetting): void;
    editorSelected(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyTextEditorAdapterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SkyTextEditorAdapterService>;
}
