import { AfterViewInit, ElementRef, OnDestroy, TemplateRef } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { SkyRequiredStateDirective } from '@skyux/forms';
import { Subject } from 'rxjs';
import { SkyTextEditorFont } from './types/font-state';
import { SkyTextEditorLinkWindowOptionsType } from './types/link-window-options-type';
import { SkyTextEditorMenuType } from './types/menu-type';
import { SkyTextEditorStyleState } from './types/style-state';
import { SkyTextEditorMergeField } from './types/text-editor-merge-field';
import { SkyTextEditorToolbarActionType } from './types/toolbar-action-type';
import * as i0 from "@angular/core";
import * as i1 from "@skyux/forms";
/**
 * The text editor component lets users format and manipulate text.
 */
export declare class SkyTextEditorComponent implements AfterViewInit, OnDestroy, ControlValueAccessor {
    #private;
    /**
     * Whether to put focus on the editor after it renders.
     */
    autofocus: boolean | undefined;
    /**
     * Whether to disable the text editor on template-driven forms. Don't use this input on reactive forms because they may overwrite the input or leave the control out of sync.
     * To set the disabled state on reactive forms, use the `FormControl` instead.
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * The fonts to include in the font picker.
     * @default [{name: 'Blackbaud Sans', value: '"Blackbaud Sans", Arial, sans-serif'}, {name: 'Arial', value: 'Arial'}, {name: 'Arial Black', value: '"Arial Black"'}, {name: 'Courier New', value: '"Courier New"'}, {name: 'Georgia', value: 'Georgia, serif'}, {name: 'Tahoma', value: 'Tahoma, Geneva, sans-serif'}, {name: 'Times New Roman', value: '"Times New Roman"'}, {name: 'Trebuchet MS', value: '"Trebuchet MS", sans-serif'}, {name: 'Verdana', value: 'Verdana, Geneva, sans-serif'}]
     */
    set fontList(value: SkyTextEditorFont[] | undefined);
    get fontList(): SkyTextEditorFont[];
    /**
     * The font sizes to include in the font size picker.
     * @default [6, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 20, 22, 24, 26, 28, 36, 48]
     */
    set fontSizeList(value: number[] | undefined);
    get fontSizeList(): number[];
    /**
     * The content of the help popover. When specified along with `labelText`, a [help inline](https://developer.blackbaud.com/skyux/components/help-inline)
     * button is added to the text editor. The help inline button displays a [popover](https://developer.blackbaud.com/skyux/components/popover)
     * when clicked using the specified content and optional title. This property only applies when `labelText` is also specified.
     */
    helpPopoverContent: string | TemplateRef<unknown> | undefined;
    /**
     * The title of the help popover. This property only applies when `helpPopoverContent` is
     * also specified.
     */
    helpPopoverTitle: string | undefined;
    /**
     * [Persistent inline help text](https://developer.blackbaud.com/skyux/design/guidelines/user-assistance#inline-help) that provides
     * additional context to the user.
     */
    hintText: string | undefined;
    /**
     * The unique ID attribute for the text editor.
     * By default, the component generates a random ID.
     */
    set id(value: string | undefined);
    get id(): string;
    /**
     * The initial styles for all content, including background color, font size, and link state.
     */
    set initialStyleState(state: SkyTextEditorStyleState | undefined);
    get initialStyleState(): SkyTextEditorStyleState;
    /**
     * The text to display as the text editor's label.
     */
    set labelText(value: string | undefined);
    get labelText(): string | undefined;
    /**
     * The menus to include in the menu bar.
     * @default [ 'edit', 'format' ]
     */
    set menus(value: SkyTextEditorMenuType[] | undefined);
    get menus(): SkyTextEditorMenuType[];
    /**
     * The merge fields to include in the merge field menu.
     */
    set mergeFields(value: SkyTextEditorMergeField[] | undefined);
    get mergeFields(): SkyTextEditorMergeField[];
    /**
     * Placeholder text to display when the text entry area is empty.
     */
    set placeholder(value: string | undefined);
    get placeholder(): string;
    /**
     * Whether the text editor is stacked on another form component. When specified,
     * the appropriate vertical spacing is automatically added to the text editor.
     */
    stacked: boolean;
    /**
     * The actions to include in the toolbar in the specified order.
     * @default [ 'font-family', 'font-size', 'font-style', 'color', 'list', 'link ]
     */
    set toolbarActions(value: SkyTextEditorToolbarActionType[] | undefined);
    get toolbarActions(): SkyTextEditorToolbarActionType[];
    /**
     * The target window options for adding a hyperlink.
     * @default [ 'new', 'existing' ]
     */
    set linkWindowOptions(value: SkyTextEditorLinkWindowOptionsType[] | undefined);
    get linkWindowOptions(): SkyTextEditorLinkWindowOptionsType[];
    /**
     * A help key that identifies the global help content to display. When specified along with `labelText`, a [help inline](https://developer.blackbaud.com/skyux/components/help-inline)
     * button is placed beside the text editor label. Clicking the button invokes [global help](https://developer.blackbaud.com/skyux/learn/develop/global-help)
     * as configured by the application. This property only applies when `labelText` is also specified.
     */
    helpKey: string | undefined;
    iframeRef: ElementRef | undefined;
    /**
     * The internal value of the control.
     */
    set value(value: string | undefined);
    get value(): string;
    inputTemplateRef: TemplateRef<unknown> | undefined;
    editorFocusStream: Subject<void>;
    formControlClass: boolean;
    protected editorFocused: boolean;
    protected readonly errorId: string;
    protected readonly ngControl: NgControl;
    protected readonly requiredState: SkyRequiredStateDirective;
    constructor();
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onIframeLoad(): void;
    /**
     * Implemented as part of ControlValueAccessor.
     */
    writeValue(value: string): void;
    /**
     * Implemented as part of ControlValueAccessor.
     */
    registerOnChange(fn: (value: any) => void): void;
    /**
     * Implemented as part of ControlValueAccessor.
     */
    registerOnTouched(fn: () => void): void;
    /**
     * Implemented as part of ControlValueAccessor.
     */
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyTextEditorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyTextEditorComponent, "sky-text-editor", never, { "autofocus": { "alias": "autofocus"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "fontList": { "alias": "fontList"; "required": false; }; "fontSizeList": { "alias": "fontSizeList"; "required": false; }; "helpPopoverContent": { "alias": "helpPopoverContent"; "required": false; }; "helpPopoverTitle": { "alias": "helpPopoverTitle"; "required": false; }; "hintText": { "alias": "hintText"; "required": false; }; "id": { "alias": "id"; "required": false; }; "initialStyleState": { "alias": "initialStyleState"; "required": false; }; "labelText": { "alias": "labelText"; "required": false; }; "menus": { "alias": "menus"; "required": false; }; "mergeFields": { "alias": "mergeFields"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "stacked": { "alias": "stacked"; "required": false; }; "toolbarActions": { "alias": "toolbarActions"; "required": false; }; "linkWindowOptions": { "alias": "linkWindowOptions"; "required": false; }; "helpKey": { "alias": "helpKey"; "required": false; }; }, {}, never, ["sky-form-error"], true, [{ directive: typeof i1.SkyRequiredStateDirective; inputs: { "required": "required"; }; outputs: {}; }]>;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_stacked: unknown;
}
